Class: Google::Apis::NetworkservicesV1beta1::AgentGateway

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

AgentGateway represents the agent gateway resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AgentGateway

Returns a new instance of AgentGateway.



97
98
99
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 97

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_gateway_cardGoogle::Apis::NetworkservicesV1beta1::AgentGatewayAgentGatewayOutputCard

AgentGatewayOutputCard contains informational output-only fields Corresponds to the JSON property agentGatewayCard



32
33
34
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 32

def agent_gateway_card
  @agent_gateway_card
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


37
38
39
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 37

def create_time
  @create_time
end

#descriptionString

Optional. A free-text description of the resource. Max length 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


42
43
44
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 42

def description
  @description
end

#etagString

Optional. Etag of the resource. If this is provided, it must match the server' s etag. If the provided etag does not match the server's etag, the request will fail with a 409 ABORTED error. Corresponds to the JSON property etag

Returns:

  • (String)


49
50
51
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 49

def etag
  @etag
end

#google_managedGoogle::Apis::NetworkservicesV1beta1::AgentGatewayGoogleManaged

Configuration for Google Managed deployment mode. Proxy is orchestrated and managed by GoogleCloud in a tenant project. Corresponds to the JSON property googleManaged



55
56
57
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 55

def google_managed
  @google_managed
end

#labelsHash<String,String>

Optional. Set of label tags associated with the AgentGateway resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


60
61
62
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 60

def labels
  @labels
end

#nameString

Identifier. Name of the AgentGateway resource. It matches pattern projects/*/ locations/*/agentGateways/. Corresponds to the JSON property name

Returns:

  • (String)


66
67
68
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 66

def name
  @name
end

#network_configGoogle::Apis::NetworkservicesV1beta1::AgentGatewayNetworkConfig

NetworkConfig contains network configurations for the AgentGateway. Corresponds to the JSON property networkConfig



71
72
73
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 71

def network_config
  @network_config
end

#protocolsArray<String>

Required. List of protocols supported by an Agent Gateway Corresponds to the JSON property protocols

Returns:

  • (Array<String>)


76
77
78
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 76

def protocols
  @protocols
end

#registriesArray<String>

Optional. A list of Agent registries containing the agents, MCP servers and tools governed by the Agent Gateway. Note: Currently limited to project-scoped registries Must be of format //agentregistry.googleapis.com/projects/project /locations/location/ Corresponds to the JSON propertyregistries`

Returns:

  • (Array<String>)


84
85
86
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 84

def registries
  @registries
end

#self_managedGoogle::Apis::NetworkservicesV1beta1::AgentGatewaySelfManaged

Configuration for Self Managed deployment mode. Attach to existing Application Load Balancers or Secure Web Proxies. Corresponds to the JSON property selfManaged



90
91
92
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 90

def self_managed
  @self_managed
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


95
96
97
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 95

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 102

def update!(**args)
  @agent_gateway_card = args[:agent_gateway_card] if args.key?(:agent_gateway_card)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @google_managed = args[:google_managed] if args.key?(:google_managed)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network_config = args[:network_config] if args.key?(:network_config)
  @protocols = args[:protocols] if args.key?(:protocols)
  @registries = args[:registries] if args.key?(:registries)
  @self_managed = args[:self_managed] if args.key?(:self_managed)
  @update_time = args[:update_time] if args.key?(:update_time)
end