Class: Google::Apis::NetworkservicesV1beta1::AgentGatewaySelfManaged

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Configuration for Self Managed deployment mode. Attach to existing Application Load Balancers or Secure Web Proxies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AgentGatewaySelfManaged

Returns a new instance of AgentGatewaySelfManaged.



265
266
267
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 265

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_uriString

Optional. A supported Google Cloud networking proxy in the Project and Location Corresponds to the JSON property resourceUri

Returns:

  • (String)


257
258
259
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 257

def resource_uri
  @resource_uri
end

#resource_urisArray<String>

Optional. List of supported Google Cloud networking proxies in the Project and Location. resource_uris is mutually exclusive with resource_uri. Corresponds to the JSON property resourceUris

Returns:

  • (Array<String>)


263
264
265
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 263

def resource_uris
  @resource_uris
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



270
271
272
273
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 270

def update!(**args)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
  @resource_uris = args[:resource_uris] if args.key?(:resource_uris)
end