Class: Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchCondition
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
Conditions to match against the incoming request.
Instance Attribute Summary collapse
-
#to ⇒ Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchConditionTo
Describes properties of one or more destinations of a request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExtensionBindingMatchCondition
constructor
A new instance of ExtensionBindingMatchCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExtensionBindingMatchCondition
Returns a new instance of ExtensionBindingMatchCondition.
851 852 853 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 851 def initialize(**args) update!(**args) end |
Instance Attribute Details
#to ⇒ Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchConditionTo
Describes properties of one or more destinations of a request.
Corresponds to the JSON property to
849 850 851 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 849 def to @to end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
856 857 858 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 856 def update!(**args) @to = args[:to] if args.key?(:to) end |