Class: Google::Apis::NetworkservicesV1beta1::ExtensionChainMatchCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Conditions under which this chain is invoked for a request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExtensionChainMatchCondition

Returns a new instance of ExtensionChainMatchCondition.



1314
1315
1316
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1314

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cel_expressionString

Required. A Common Expression Language (CEL) expression that is used to match requests for which the extension chain is executed. For more information, see CEL matcher language reference. Corresponds to the JSON property celExpression

Returns:

  • (String)


1312
1313
1314
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1312

def cel_expression
  @cel_expression
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1319
1320
1321
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1319

def update!(**args)
  @cel_expression = args[:cel_expression] if args.key?(:cel_expression)
end