Class: Google::Apis::NetworkservicesV1beta1::GrpcRouteRouteRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Describes how to route traffic.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrpcRouteRouteRule

Returns a new instance of GrpcRouteRouteRule.



1621
1622
1623
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1621

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionGoogle::Apis::NetworkservicesV1beta1::GrpcRouteRouteAction

Specifies how to route matched traffic. Corresponds to the JSON property action



1611
1612
1613
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1611

def action
  @action
end

#matchesArray<Google::Apis::NetworkservicesV1beta1::GrpcRouteRouteMatch>

Optional. Matches define conditions used for matching the rule against incoming gRPC requests. Each match is independent, i.e. this rule will be matched if ANY one of the matches is satisfied. If no matches field is specified, this rule will unconditionally match traffic. Corresponds to the JSON property matches



1619
1620
1621
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1619

def matches
  @matches
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1626
1627
1628
1629
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1626

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @matches = args[:matches] if args.key?(:matches)
end