Class: Google::Apis::NetworkservicesV1beta1::HttpRouteHeaderMatch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Specifies how to select a route rule based on HTTP request headers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpRouteHeaderMatch

Returns a new instance of HttpRouteHeaderMatch.



2010
2011
2012
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2010

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exact_matchString

The value of the header should match exactly the content of exact_match. Corresponds to the JSON property exactMatch

Returns:

  • (String)


1967
1968
1969
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1967

def exact_match
  @exact_match
end

#headerString

The name of the HTTP header to match against. Corresponds to the JSON property header

Returns:

  • (String)


1972
1973
1974
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1972

def header
  @header
end

#invert_matchBoolean Also known as: invert_match?

If specified, the match result will be inverted before checking. Default value is set to false. Corresponds to the JSON property invertMatch

Returns:

  • (Boolean)


1978
1979
1980
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1978

def invert_match
  @invert_match
end

#prefix_matchString

The value of the header must start with the contents of prefix_match. Corresponds to the JSON property prefixMatch

Returns:

  • (String)


1984
1985
1986
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1984

def prefix_match
  @prefix_match
end

#present_matchBoolean Also known as: present_match?

A header with header_name must exist. The match takes place whether or not the header has a value. Corresponds to the JSON property presentMatch

Returns:

  • (Boolean)


1990
1991
1992
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1990

def present_match
  @present_match
end

#range_matchGoogle::Apis::NetworkservicesV1beta1::HttpRouteHeaderMatchIntegerRange

Represents an integer value range. Corresponds to the JSON property rangeMatch



1996
1997
1998
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1996

def range_match
  @range_match
end

#regex_matchString

The value of the header must match the regular expression specified in regex_match. For regular expression grammar, please see: https://github.com/ google/re2/wiki/Syntax Corresponds to the JSON property regexMatch

Returns:

  • (String)


2003
2004
2005
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2003

def regex_match
  @regex_match
end

#suffix_matchString

The value of the header must end with the contents of suffix_match. Corresponds to the JSON property suffixMatch

Returns:

  • (String)


2008
2009
2010
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2008

def suffix_match
  @suffix_match
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2015

def update!(**args)
  @exact_match = args[:exact_match] if args.key?(:exact_match)
  @header = args[:header] if args.key?(:header)
  @invert_match = args[:invert_match] if args.key?(:invert_match)
  @prefix_match = args[:prefix_match] if args.key?(:prefix_match)
  @present_match = args[:present_match] if args.key?(:present_match)
  @range_match = args[:range_match] if args.key?(:range_match)
  @regex_match = args[:regex_match] if args.key?(:regex_match)
  @suffix_match = args[:suffix_match] if args.key?(:suffix_match)
end