Class: Google::Apis::NetworkservicesV1beta1::HttpRouteHeaderModifier

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

The specification for modifying HTTP header in HTTP request and HTTP response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpRouteHeaderModifier

Returns a new instance of HttpRouteHeaderModifier.



2432
2433
2434
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2432

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addHash<String,String>

Add the headers with given map where key is the name of the header, value is the value of the header. Corresponds to the JSON property add

Returns:

  • (Hash<String,String>)


2419
2420
2421
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2419

def add
  @add
end

#removeArray<String>

Remove headers (matching by header names) specified in the list. Corresponds to the JSON property remove

Returns:

  • (Array<String>)


2424
2425
2426
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2424

def remove
  @remove
end

#setHash<String,String>

Completely overwrite/replace the headers with given map where key is the name of the header, value is the value of the header. Corresponds to the JSON property set

Returns:

  • (Hash<String,String>)


2430
2431
2432
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2430

def set
  @set
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2437
2438
2439
2440
2441
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2437

def update!(**args)
  @add = args[:add] if args.key?(:add)
  @remove = args[:remove] if args.key?(:remove)
  @set = args[:set] if args.key?(:set)
end