Class: Google::Apis::NetworkservicesV1beta1::HttpRouteQueryParameterMatch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Specifications to match a query parameter in the request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpRouteQueryParameterMatch

Returns a new instance of HttpRouteQueryParameterMatch.



1988
1989
1990
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1988

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exact_matchString

The value of the query parameter must exactly match the contents of exact_match. Only one of exact_match, regex_match, or present_match must be set. Corresponds to the JSON property exactMatch

Returns:

  • (String)


1965
1966
1967
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1965

def exact_match
  @exact_match
end

#present_matchBoolean Also known as: present_match?

Specifies that the QueryParameterMatcher matches if request contains query parameter, irrespective of whether the parameter has a value or not. Only one of exact_match, regex_match, or present_match must be set. Corresponds to the JSON property presentMatch

Returns:

  • (Boolean)


1972
1973
1974
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1972

def present_match
  @present_match
end

#query_parameterString

The name of the query parameter to match. Corresponds to the JSON property queryParameter

Returns:

  • (String)


1978
1979
1980
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1978

def query_parameter
  @query_parameter
end

#regex_matchString

The value of the query parameter must match the regular expression specified by regex_match. For regular expression grammar, please see https://github.com/ google/re2/wiki/Syntax Only one of exact_match, regex_match, or present_match must be set. Corresponds to the JSON property regexMatch

Returns:

  • (String)


1986
1987
1988
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1986

def regex_match
  @regex_match
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1993
1994
1995
1996
1997
1998
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1993

def update!(**args)
  @exact_match = args[:exact_match] if args.key?(:exact_match)
  @present_match = args[:present_match] if args.key?(:present_match)
  @query_parameter = args[:query_parameter] if args.key?(:query_parameter)
  @regex_match = args[:regex_match] if args.key?(:regex_match)
end