Class: Google::Apis::NetworkservicesV1beta1::HttpRouteRequestMirrorPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Specifies the policy on how requests are shadowed to a separate mirrored destination service. The proxy does not wait for responses from the shadow service. Prior to sending traffic to the shadow service, the host/authority header is suffixed with -shadow. Mirroring is currently not supported for Cloud Run destinations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpRouteRequestMirrorPolicy

Returns a new instance of HttpRouteRequestMirrorPolicy.



1805
1806
1807
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1805

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationGoogle::Apis::NetworkservicesV1beta1::HttpRouteDestination

Specifications of a destination to which the request should be routed to. Corresponds to the JSON property destination



1797
1798
1799
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1797

def destination
  @destination
end

#mirror_percentFloat

Optional. The percentage of requests to get mirrored to the desired destination. Corresponds to the JSON property mirrorPercent

Returns:

  • (Float)


1803
1804
1805
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1803

def mirror_percent
  @mirror_percent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1810
1811
1812
1813
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1810

def update!(**args)
  @destination = args[:destination] if args.key?(:destination)
  @mirror_percent = args[:mirror_percent] if args.key?(:mirror_percent)
end