Class: Google::Apis::NetworkservicesV1beta1::HttpRouteRouteAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

The specifications for routing traffic and applying associated policies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpRouteRouteAction

Returns a new instance of HttpRouteRouteAction.



2753
2754
2755
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2753

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cors_policyGoogle::Apis::NetworkservicesV1beta1::HttpRouteCorsPolicy

The Specification for allowing client side cross-origin requests. Corresponds to the JSON property corsPolicy



2670
2671
2672
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2670

def cors_policy
  @cors_policy
end

#destinationsArray<Google::Apis::NetworkservicesV1beta1::HttpRouteDestination>

The destination to which traffic should be forwarded. Corresponds to the JSON property destinations



2675
2676
2677
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2675

def destinations
  @destinations
end

#direct_responseGoogle::Apis::NetworkservicesV1beta1::HttpRouteHttpDirectResponse

Static HTTP response object to be returned. Corresponds to the JSON property directResponse



2680
2681
2682
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2680

def direct_response
  @direct_response
end

#fault_injection_policyGoogle::Apis::NetworkservicesV1beta1::HttpRouteFaultInjectionPolicy

The specification for fault injection introduced into traffic to test the resiliency of clients to destination service failure. As part of fault injection, when clients send requests to a destination, delays can be introduced by client proxy on a percentage of requests before sending those requests to the destination service. Similarly requests can be aborted by client proxy for a percentage of requests. Corresponds to the JSON property faultInjectionPolicy



2690
2691
2692
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2690

def fault_injection_policy
  @fault_injection_policy
end

#idle_timeoutString

Optional. Specifies the idle timeout for the selected route. The idle timeout is defined as the period in which there are no bytes sent or received on either the upstream or downstream connection. If not set, the default idle timeout is 1 hour. If set to 0s, the timeout will be disabled. Corresponds to the JSON property idleTimeout

Returns:

  • (String)


2698
2699
2700
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2698

def idle_timeout
  @idle_timeout
end

#redirectGoogle::Apis::NetworkservicesV1beta1::HttpRouteRedirect

The specification for redirecting traffic. Corresponds to the JSON property redirect



2703
2704
2705
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2703

def redirect
  @redirect
end

#request_header_modifierGoogle::Apis::NetworkservicesV1beta1::HttpRouteHeaderModifier

The specification for modifying HTTP header in HTTP request and HTTP response. Corresponds to the JSON property requestHeaderModifier



2708
2709
2710
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2708

def request_header_modifier
  @request_header_modifier
end

#request_mirror_policyGoogle::Apis::NetworkservicesV1beta1::HttpRouteRequestMirrorPolicy

Specifies the policy on how requests are shadowed to a separate mirrored destination service. The proxy does not wait for responses from the shadow service. Prior to sending traffic to the shadow service, the host/authority header is suffixed with -shadow. Mirroring is currently not supported for Cloud Run destinations. Corresponds to the JSON property requestMirrorPolicy



2717
2718
2719
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2717

def request_mirror_policy
  @request_mirror_policy
end

#response_header_modifierGoogle::Apis::NetworkservicesV1beta1::HttpRouteHeaderModifier

The specification for modifying HTTP header in HTTP request and HTTP response. Corresponds to the JSON property responseHeaderModifier



2722
2723
2724
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2722

def response_header_modifier
  @response_header_modifier
end

#retry_policyGoogle::Apis::NetworkservicesV1beta1::HttpRouteRetryPolicy

The specifications for retries. Corresponds to the JSON property retryPolicy



2727
2728
2729
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2727

def retry_policy
  @retry_policy
end

#stateful_session_affinityGoogle::Apis::NetworkservicesV1beta1::HttpRouteStatefulSessionAffinityPolicy

The specification for cookie-based stateful session affinity where the date plane supplies a “session cookie” with the name "GSSA" which encodes a specific destination host and each request containing that cookie will be directed to that host as long as the destination host remains up and healthy. The gRPC proxyless mesh library or sidecar proxy will manage the session cookie but the client application code is responsible for copying the cookie from each RPC in the session to the next. Corresponds to the JSON property statefulSessionAffinity



2738
2739
2740
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2738

def stateful_session_affinity
  @stateful_session_affinity
end

#timeoutString

Specifies the timeout for selected route. Timeout is computed from the time the request has been fully processed (i.e. end of stream) up until the response has been completely processed. Timeout includes all retries. Corresponds to the JSON property timeout

Returns:

  • (String)


2745
2746
2747
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2745

def timeout
  @timeout
end

#url_rewriteGoogle::Apis::NetworkservicesV1beta1::HttpRouteUrlRewrite

The specification for modifying the URL of the request, prior to forwarding the request to the destination. Corresponds to the JSON property urlRewrite



2751
2752
2753
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2751

def url_rewrite
  @url_rewrite
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
2769
2770
2771
2772
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2758

def update!(**args)
  @cors_policy = args[:cors_policy] if args.key?(:cors_policy)
  @destinations = args[:destinations] if args.key?(:destinations)
  @direct_response = args[:direct_response] if args.key?(:direct_response)
  @fault_injection_policy = args[:fault_injection_policy] if args.key?(:fault_injection_policy)
  @idle_timeout = args[:idle_timeout] if args.key?(:idle_timeout)
  @redirect = args[:redirect] if args.key?(:redirect)
  @request_header_modifier = args[:request_header_modifier] if args.key?(:request_header_modifier)
  @request_mirror_policy = args[:request_mirror_policy] if args.key?(:request_mirror_policy)
  @response_header_modifier = args[:response_header_modifier] if args.key?(:response_header_modifier)
  @retry_policy = args[:retry_policy] if args.key?(:retry_policy)
  @stateful_session_affinity = args[:stateful_session_affinity] if args.key?(:stateful_session_affinity)
  @timeout = args[:timeout] if args.key?(:timeout)
  @url_rewrite = args[:url_rewrite] if args.key?(:url_rewrite)
end