Class: Google::Apis::NetworkservicesV1beta1::HttpRouteUrlRewrite

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

The specification for modifying the URL of the request, prior to forwarding the request to the destination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpRouteUrlRewrite

Returns a new instance of HttpRouteUrlRewrite.



2406
2407
2408
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2406

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#host_rewriteString

Prior to forwarding the request to the selected destination, the requests host header is replaced by this value. Corresponds to the JSON property hostRewrite

Returns:

  • (String)


2398
2399
2400
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2398

def host_rewrite
  @host_rewrite
end

#path_prefix_rewriteString

Prior to forwarding the request to the selected destination, the matching portion of the requests path is replaced by this value. Corresponds to the JSON property pathPrefixRewrite

Returns:

  • (String)


2404
2405
2406
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2404

def path_prefix_rewrite
  @path_prefix_rewrite
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2411
2412
2413
2414
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2411

def update!(**args)
  @host_rewrite = args[:host_rewrite] if args.key?(:host_rewrite)
  @path_prefix_rewrite = args[:path_prefix_rewrite] if args.key?(:path_prefix_rewrite)
end