Class: Google::Apis::NetworkservicesV1beta1::ListGatewayRouteViewsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Response returned by the ListGatewayRouteViews method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListGatewayRouteViewsResponse

Returns a new instance of ListGatewayRouteViewsResponse.



3456
3457
3458
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3456

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gateway_route_viewsArray<Google::Apis::NetworkservicesV1beta1::GatewayRouteView>

List of GatewayRouteView resources. Corresponds to the JSON property gatewayRouteViews



3441
3442
3443
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3441

def gateway_route_views
  @gateway_route_views
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3447
3448
3449
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3447

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unreachable resources. Populated when the request attempts to list all resources across all supported locations, while some locations are temporarily unavailable. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3454
3455
3456
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3454

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3461
3462
3463
3464
3465
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3461

def update!(**args)
  @gateway_route_views = args[:gateway_route_views] if args.key?(:gateway_route_views)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end