Class: Google::Apis::NetworkservicesV1beta1::ListGatewaysResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Response returned by the ListGateways method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListGatewaysResponse

Returns a new instance of ListGatewaysResponse.



2579
2580
2581
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2579

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gatewaysArray<Google::Apis::NetworkservicesV1beta1::Gateway>

List of Gateway resources. Corresponds to the JSON property gateways



2565
2566
2567
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2565

def gateways
  @gateways
end

#next_page_tokenString

If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2572
2573
2574
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2572

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2577
2578
2579
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2577

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2584
2585
2586
2587
2588
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2584

def update!(**args)
  @gateways = args[:gateways] if args.key?(:gateways)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end