Class: Google::Apis::NetworkservicesV1beta1::ListHttpRoutesResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::ListHttpRoutesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
Response returned by the ListHttpRoutes method.
Instance Attribute Summary collapse
-
#http_routes ⇒ Array<Google::Apis::NetworkservicesV1beta1::HttpRoute>
List of HttpRoute resources.
-
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_tokenis included. -
#unreachable ⇒ Array<String>
Unreachable resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListHttpRoutesResponse
constructor
A new instance of ListHttpRoutesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListHttpRoutesResponse
Returns a new instance of ListHttpRoutesResponse.
2649 2650 2651 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2649 def initialize(**args) update!(**args) end |
Instance Attribute Details
#http_routes ⇒ Array<Google::Apis::NetworkservicesV1beta1::HttpRoute>
List of HttpRoute resources.
Corresponds to the JSON property httpRoutes
2633 2634 2635 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2633 def http_routes @http_routes end |
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this method
again using the value of next_page_token as page_token.
Corresponds to the JSON property nextPageToken
2640 2641 2642 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2640 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unreachable resources. Populated when the request opts into
return_partial_success and reading across collections e.g. when attempting to
list all resources across all supported locations.
Corresponds to the JSON property unreachable
2647 2648 2649 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2647 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2654 2655 2656 2657 2658 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2654 def update!(**args) @http_routes = args[:http_routes] if args.key?(:http_routes) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |