Class: Google::Apis::NetworkservicesV1beta1::ListLbTrafficExtensionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::ListLbTrafficExtensionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
Message for response to listing LbTrafficExtension resources.
Instance Attribute Summary collapse
-
#lb_traffic_extensions ⇒ Array<Google::Apis::NetworkservicesV1beta1::LbTrafficExtension>
The list of
LbTrafficExtensionresources. -
#next_page_token ⇒ String
A token identifying a page of results that the server returns.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLbTrafficExtensionsResponse
constructor
A new instance of ListLbTrafficExtensionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLbTrafficExtensionsResponse
Returns a new instance of ListLbTrafficExtensionsResponse.
3106 3107 3108 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3106 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lb_traffic_extensions ⇒ Array<Google::Apis::NetworkservicesV1beta1::LbTrafficExtension>
The list of LbTrafficExtension resources.
Corresponds to the JSON property lbTrafficExtensions
3094 3095 3096 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3094 def lb_traffic_extensions @lb_traffic_extensions end |
#next_page_token ⇒ String
A token identifying a page of results that the server returns.
Corresponds to the JSON property nextPageToken
3099 3100 3101 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3099 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
3104 3105 3106 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3104 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3111 3112 3113 3114 3115 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3111 def update!(**args) @lb_traffic_extensions = args[:lb_traffic_extensions] if args.key?(:lb_traffic_extensions) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |