Class: Google::Apis::NetworkservicesV1beta1::ListMeshesResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::ListMeshesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
Response returned by the ListMeshes method.
Instance Attribute Summary collapse
-
#meshes ⇒ Array<Google::Apis::NetworkservicesV1beta1::Mesh>
List of Mesh resources.
-
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_tokenis included. -
#unreachable ⇒ Array<String>
Unreachable resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMeshesResponse
constructor
A new instance of ListMeshesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMeshesResponse
Returns a new instance of ListMeshesResponse.
3777 3778 3779 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#meshes ⇒ Array<Google::Apis::NetworkservicesV1beta1::Mesh>
List of Mesh resources.
Corresponds to the JSON property meshes
3761 3762 3763 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3761 def meshes @meshes end |
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this method
again using the value of next_page_token as page_token.
Corresponds to the JSON property nextPageToken
3768 3769 3770 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3768 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unreachable resources. Populated when the request opts into
return_partial_success and reading across collections e.g. when attempting to
list all resources across all supported locations.
Corresponds to the JSON property unreachable
3775 3776 3777 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3775 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3782 3783 3784 3785 3786 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3782 def update!(**args) @meshes = args[:meshes] if args.key?(:meshes) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |