Class: Google::Apis::NetworkservicesV1beta1::ListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOperationsResponse

Returns a new instance of ListOperationsResponse.



3234
3235
3236
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3234

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3219
3220
3221
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3219

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::NetworkservicesV1beta1::Operation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



3224
3225
3226
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3224

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3232
3233
3234
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3232

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3239
3240
3241
3242
3243
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3239

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end