Class: Google::Apis::NetworkservicesV1beta1::ListProducerExtensionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::ListProducerExtensionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
Response returned by the ListProducerExtensions method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_tokenis included. -
#producer_extensions ⇒ Array<Google::Apis::NetworkservicesV1beta1::ProducerExtension>
List of
ProducerExtensionresources. -
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListProducerExtensionsResponse
constructor
A new instance of ListProducerExtensionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListProducerExtensionsResponse
Returns a new instance of ListProducerExtensionsResponse.
3847 3848 3849 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3847 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this method
again using the value of next_page_token as page_token.
Corresponds to the JSON property nextPageToken
3832 3833 3834 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3832 def next_page_token @next_page_token end |
#producer_extensions ⇒ Array<Google::Apis::NetworkservicesV1beta1::ProducerExtension>
List of ProducerExtension resources.
Corresponds to the JSON property producerExtensions
3837 3838 3839 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3837 def producer_extensions @producer_extensions end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request attempts to
list all resources across all supported locations, while some locations are
temporarily unavailable. The resource names are in the format: projects/
project/locations/location/producerExtensions/producer_extension`.
Corresponds to the JSON propertyunreachable`
3845 3846 3847 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3845 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3852 3853 3854 3855 3856 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3852 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @producer_extensions = args[:producer_extensions] if args.key?(:producer_extensions) @unreachable = args[:unreachable] if args.key?(:unreachable) end |