Class: Google::Apis::NetworkservicesV1beta1::ListServiceBindingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Response returned by the ListServiceBindings method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListServiceBindingsResponse

Returns a new instance of ListServiceBindingsResponse.



3280
3281
3282
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3280

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3266
3267
3268
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3266

def next_page_token
  @next_page_token
end

#service_bindingsArray<Google::Apis::NetworkservicesV1beta1::ServiceBinding>

List of ServiceBinding resources. Corresponds to the JSON property serviceBindings



3271
3272
3273
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3271

def service_bindings
  @service_bindings
end

#unreachableArray<String>

Unreachable resources. Populated when the request attempts to list all resources across all supported locations, while some locations are temporarily unavailable. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3278
3279
3280
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3278

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3285
3286
3287
3288
3289
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3285

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @service_bindings = args[:service_bindings] if args.key?(:service_bindings)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end