Class: Google::Apis::NetworkservicesV1beta1::ListServiceLbPoliciesResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::ListServiceLbPoliciesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
Response returned by the ListServiceLbPolicies method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_tokenis included. -
#service_lb_policies ⇒ Array<Google::Apis::NetworkservicesV1beta1::ServiceLbPolicy>
List of ServiceLbPolicy resources.
-
#unreachable ⇒ Array<String>
Unreachable resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListServiceLbPoliciesResponse
constructor
A new instance of ListServiceLbPoliciesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListServiceLbPoliciesResponse
Returns a new instance of ListServiceLbPoliciesResponse.
3304 3305 3306 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3304 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this method
again using the value of next_page_token as page_token.
Corresponds to the JSON property nextPageToken
3290 3291 3292 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3290 def next_page_token @next_page_token end |
#service_lb_policies ⇒ Array<Google::Apis::NetworkservicesV1beta1::ServiceLbPolicy>
List of ServiceLbPolicy resources.
Corresponds to the JSON property serviceLbPolicies
3295 3296 3297 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3295 def service_lb_policies @service_lb_policies end |
#unreachable ⇒ Array<String>
Unreachable resources. Populated when the request attempts to list all
resources across all supported locations, while some locations are temporarily
unavailable.
Corresponds to the JSON property unreachable
3302 3303 3304 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3302 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3309 3310 3311 3312 3313 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3309 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @service_lb_policies = args[:service_lb_policies] if args.key?(:service_lb_policies) @unreachable = args[:unreachable] if args.key?(:unreachable) end |