Class: Google::Apis::NetworkservicesV1beta1::ListTlsRoutesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Response returned by the ListTlsRoutes method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListTlsRoutesResponse

Returns a new instance of ListTlsRoutesResponse.



3385
3386
3387
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3385

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3371
3372
3373
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3371

def next_page_token
  @next_page_token
end

#tls_routesArray<Google::Apis::NetworkservicesV1beta1::TlsRoute>

List of TlsRoute resources. Corresponds to the JSON property tlsRoutes



3376
3377
3378
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3376

def tls_routes
  @tls_routes
end

#unreachableArray<String>

Unreachable resources. Populated when the request opts into return_partial_success and reading across collections e.g. when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3383
3384
3385
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3383

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3390
3391
3392
3393
3394
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3390

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @tls_routes = args[:tls_routes] if args.key?(:tls_routes)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end