Class: Google::Apis::NetworkservicesV1beta1::ListWasmPluginsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Response returned by the ListWasmPlugins method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListWasmPluginsResponse

Returns a new instance of ListWasmPluginsResponse.



3626
3627
3628
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3626

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3612
3613
3614
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3612

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unreachable resources. Populated when the request attempts to list all resources across all supported locations, while some locations are temporarily unavailable. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3619
3620
3621
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3619

def unreachable
  @unreachable
end

#wasm_pluginsArray<Google::Apis::NetworkservicesV1beta1::WasmPlugin>

List of WasmPlugin resources. Corresponds to the JSON property wasmPlugins



3624
3625
3626
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3624

def wasm_plugins
  @wasm_plugins
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3631
3632
3633
3634
3635
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3631

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
  @wasm_plugins = args[:wasm_plugins] if args.key?(:wasm_plugins)
end