Class: Google::Apis::NetworkservicesV1beta1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



3795
3796
3797
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


3759
3760
3761
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3759

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3764
3765
3766
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3764

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


3769
3770
3771
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3769

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have Operation. error value with a google.rpc.Status.code of 1, corresponding to Code. CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


3777
3778
3779
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3777

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


3783
3784
3785
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3783

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


3788
3789
3790
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3788

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


3793
3794
3795
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3793

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3800
3801
3802
3803
3804
3805
3806
3807
3808
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3800

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end