Class: Google::Apis::NetworkservicesV1beta1::ServiceLbPolicyFailoverConfig
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::ServiceLbPolicyFailoverConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
Option to specify health based failover behavior. This is not related to Network load balancer FailoverPolicy.
Instance Attribute Summary collapse
-
#failover_health_threshold ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceLbPolicyFailoverConfig
constructor
A new instance of ServiceLbPolicyFailoverConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceLbPolicyFailoverConfig
Returns a new instance of ServiceLbPolicyFailoverConfig.
4022 4023 4024 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4022 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failover_health_threshold ⇒ Fixnum
Optional. The percentage threshold that a load balancer will begin to send
traffic to failover backends. If the percentage of endpoints in a MIG/NEG is
smaller than this value, traffic would be sent to failover backends if
possible. This field should be set to a value between 1 and 99. The default
value is 50 for Global external HTTP(S) load balancer (classic) and Proxyless
service mesh, and 70 for others.
Corresponds to the JSON property failoverHealthThreshold
4020 4021 4022 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4020 def failover_health_threshold @failover_health_threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4027 4028 4029 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4027 def update!(**args) @failover_health_threshold = args[:failover_health_threshold] if args.key?(:failover_health_threshold) end |