Class: Google::Apis::NetworkservicesV1beta1::TlsRoute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

TlsRoute defines how traffic should be routed based on SNI and other matching L3 attributes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TlsRoute

Returns a new instance of TlsRoute.



5089
5090
5091
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 5089

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5031
5032
5033
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 5031

def create_time
  @create_time
end

#descriptionString

Optional. A free-text description of the resource. Max length 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


5036
5037
5038
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 5036

def description
  @description
end

#gatewaysArray<String>

Optional. Gateways defines a list of gateways this TlsRoute is attached to, as one of the routing rules to route the requests served by the gateway. Each gateway reference should match the pattern: projects/*/locations/*/gateways/ Corresponds to the JSON property gateways

Returns:

  • (Array<String>)


5043
5044
5045
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 5043

def gateways
  @gateways
end

#labelsHash<String,String>

Optional. Set of label tags associated with the TlsRoute resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5048
5049
5050
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 5048

def labels
  @labels
end

#meshesArray<String>

Optional. Meshes defines a list of meshes this TlsRoute is attached to, as one of the routing rules to route the requests served by the mesh. Each mesh reference should match the pattern: projects/*/locations/*/meshes/ The attached Mesh should be of a type SIDECAR Corresponds to the JSON property meshes

Returns:

  • (Array<String>)


5056
5057
5058
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 5056

def meshes
  @meshes
end

#nameString

Identifier. Name of the TlsRoute resource. It matches pattern projects/*/ locations/*/tlsRoutes/tls_route_name>. Corresponds to the JSON property name

Returns:

  • (String)


5062
5063
5064
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 5062

def name
  @name
end

#rulesArray<Google::Apis::NetworkservicesV1beta1::TlsRouteRouteRule>

Required. Rules that define how traffic is routed and handled. At least one RouteRule must be supplied. If there are multiple rules then the action taken will be the first rule to match. Corresponds to the JSON property rules



5069
5070
5071
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 5069

def rules
  @rules
end

Output only. Server-defined URL of this resource Corresponds to the JSON property selfLink

Returns:

  • (String)


5074
5075
5076
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 5074

def self_link
  @self_link
end

#target_proxiesArray<String>

Optional. TargetProxies defines a list of TargetTcpProxies this TlsRoute is attached to, as one of the routing rules to route the requests served by the TargetTcpProxy. Each TargetTcpProxy reference should match the pattern: projects/*/locations/*/targetTcpProxies/ Corresponds to the JSON property targetProxies

Returns:

  • (Array<String>)


5082
5083
5084
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 5082

def target_proxies
  @target_proxies
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5087
5088
5089
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 5087

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5094
5095
5096
5097
5098
5099
5100
5101
5102
5103
5104
5105
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 5094

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @gateways = args[:gateways] if args.key?(:gateways)
  @labels = args[:labels] if args.key?(:labels)
  @meshes = args[:meshes] if args.key?(:meshes)
  @name = args[:name] if args.key?(:name)
  @rules = args[:rules] if args.key?(:rules)
  @self_link = args[:self_link] if args.key?(:self_link)
  @target_proxies = args[:target_proxies] if args.key?(:target_proxies)
  @update_time = args[:update_time] if args.key?(:update_time)
end