Class: Google::Apis::NetworkservicesV1beta1::TlsRouteRouteRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Specifies how to match traffic and how to route traffic when traffic is matched.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TlsRouteRouteRule

Returns a new instance of TlsRouteRouteRule.



4488
4489
4490
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4488

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionGoogle::Apis::NetworkservicesV1beta1::TlsRouteRouteAction

The specifications for routing traffic and applying associated policies. Corresponds to the JSON property action



4479
4480
4481
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4479

def action
  @action
end

#matchesArray<Google::Apis::NetworkservicesV1beta1::TlsRouteRouteMatch>

Required. RouteMatch defines the predicate used to match requests to a given action. Multiple match types are "OR"ed for evaluation. Atleast one RouteMatch must be supplied. Corresponds to the JSON property matches



4486
4487
4488
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4486

def matches
  @matches
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4493
4494
4495
4496
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4493

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @matches = args[:matches] if args.key?(:matches)
end