Class: Google::Apis::NetworkservicesV1beta1::AgentConnectivityTemplate
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::AgentConnectivityTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
AgentConnectivityTemplate represents a reusable network configuration.
Instance Attribute Summary collapse
-
#access_path ⇒ String
Required.
-
#access_types ⇒ Array<String>
Optional.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#egress_network_config ⇒ Google::Apis::NetworkservicesV1beta1::EgressNetworkConfig
Optional.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AgentConnectivityTemplate
constructor
A new instance of AgentConnectivityTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AgentConnectivityTemplate
Returns a new instance of AgentConnectivityTemplate.
82 83 84 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 82 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_path ⇒ String
Required. Immutable. The path of the access. Maps roughly to ingress/egress,
though we keep CLIENT_TO_AGENT and AGENT_TO_ANYWHERE as carryovers from Agent
Gateway's original resource model. The path is immutable once set. Exactly one
path can be set.
Corresponds to the JSON property accessPath
35 36 37 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 35 def access_path @access_path end |
#access_types ⇒ Array<String>
Optional. The types of network access provided to the gateway. Both PUBLIC and
PRIVATE can be configured.
Corresponds to the JSON property accessTypes
41 42 43 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 41 def access_types @access_types end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
46 47 48 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 46 def create_time @create_time end |
#description ⇒ String
Optional. A free-text description of the resource. Max length 1024 characters.
Corresponds to the JSON property description
51 52 53 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 51 def description @description end |
#egress_network_config ⇒ Google::Apis::NetworkservicesV1beta1::EgressNetworkConfig
Optional. Configuration for egress network traffic.
Corresponds to the JSON property egressNetworkConfig
56 57 58 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 56 def egress_network_config @egress_network_config end |
#etag ⇒ String
Optional. Etag of the resource. If this is provided, it must match the server'
s etag. If the provided etag does not match the server's etag, the request
will fail with a 409 ABORTED error.
Corresponds to the JSON property etag
63 64 65 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 63 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Set of label tags associated with the AgentConnectivityTemplate
resource.
Corresponds to the JSON property labels
69 70 71 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 69 def labels @labels end |
#name ⇒ String
Identifier. Name of the AgentConnectivityTemplate resource. It matches pattern
projects/*/locations/*/agentConnectivityTemplates/.
Corresponds to the JSON property name
75 76 77 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 75 def name @name end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
80 81 82 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 80 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 87 def update!(**args) @access_path = args[:access_path] if args.key?(:access_path) @access_types = args[:access_types] if args.key?(:access_types) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @egress_network_config = args[:egress_network_config] if args.key?(:egress_network_config) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |