Class: Google::Apis::NetworkservicesV1beta1::AgentGatewaySelfManaged

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Configuration for Self Managed deployment mode. Attach to existing Application Load Balancers or Secure Web Proxies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AgentGatewaySelfManaged

Returns a new instance of AgentGatewaySelfManaged.



259
260
261
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 259

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_uriString

Optional. A supported Google Cloud networking proxy in the Project and Location Corresponds to the JSON property resourceUri

Returns:

  • (String)


257
258
259
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 257

def resource_uri
  @resource_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



264
265
266
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 264

def update!(**args)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
end