Class: Google::Apis::NetworkservicesV1beta1::ExtensionBinding
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::ExtensionBinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
ExtensionBinding is a resource representing the attachment of an extension
to a service.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#fail_open ⇒ Boolean
(also: #fail_open?)
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#match_conditions ⇒ Array<Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchCondition>
Optional.
-
#name ⇒ String
Identifier.
-
#priority ⇒ Fixnum
Optional.
-
#producer_extension ⇒ String
Required.
-
#producer_metadata ⇒ Hash<String,String>
Optional.
-
#target ⇒ Google::Apis::NetworkservicesV1beta1::ExtensionBindingTarget
Specifies a list of targets to which this
ExtensionBindingshould attach. -
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExtensionBinding
constructor
A new instance of ExtensionBinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExtensionBinding
Returns a new instance of ExtensionBinding.
821 822 823 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 821 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
748 749 750 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 748 def create_time @create_time end |
#description ⇒ String
Optional. A human-readable description of the resource.
Corresponds to the JSON property description
753 754 755 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 753 def description @description end |
#etag ⇒ String
Optional. Etag of the resource. If provided, it must match the server's etag.
If the provided etag does not match the server's etag, the request will fail
with a 409 ABORTED error.
Corresponds to the JSON property etag
760 761 762 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 760 def etag @etag end |
#fail_open ⇒ Boolean Also known as: fail_open?
Optional. Determines the behavior of the extension binding when the call to
the extension fails or times out. Default value is FALSE. When set to TRUE,
failures of the extension are silently ignored.
Corresponds to the JSON property failOpen
767 768 769 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 767 def fail_open @fail_open end |
#labels ⇒ Hash<String,String>
Optional. Set of labels associated with the ExtensionBinding resource. The
format must comply with the following requirements.
Corresponds to the JSON property labels
775 776 777 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 775 def labels @labels end |
#match_conditions ⇒ Array<Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchCondition>
Optional. A list of match conditions to match against the incoming request.
The extension will be invoked if at least one condition matches the request,
or if no match conditions are specified. Limited to 5 conditions.
Corresponds to the JSON property matchConditions
782 783 784 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 782 def match_conditions @match_conditions end |
#name ⇒ String
Identifier. Name of the ExtensionBinding resource in the following format:
projects/project/locations/location/extensionBindings/extension_binding`.
Corresponds to the JSON propertyname`
788 789 790 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 788 def name @name end |
#priority ⇒ Fixnum
Optional. Priority of the extension binding. Lower numbers indicate higher
priority. Priority of extension bindings are used to determine the order in
which extension bindings are applied to a request.
Corresponds to the JSON property priority
795 796 797 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 795 def priority @priority end |
#producer_extension ⇒ String
Required. The name of the extension that this binding should attach to target
resources. Format: For Google-provided extensions, specify the service
endpoint (see Model Armor integration)
Corresponds to the JSON property producerExtension
803 804 805 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 803 def producer_extension @producer_extension end |
#producer_metadata ⇒ Hash<String,String>
Optional. Additional metadata that should be passed to the attached extension
with each request.
Corresponds to the JSON property producerMetadata
809 810 811 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 809 def @producer_metadata end |
#target ⇒ Google::Apis::NetworkservicesV1beta1::ExtensionBindingTarget
Specifies a list of targets to which this ExtensionBinding should attach.
Corresponds to the JSON property target
814 815 816 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 814 def target @target end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
819 820 821 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 819 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
826 827 828 829 830 831 832 833 834 835 836 837 838 839 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 826 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @fail_open = args[:fail_open] if args.key?(:fail_open) @labels = args[:labels] if args.key?(:labels) @match_conditions = args[:match_conditions] if args.key?(:match_conditions) @name = args[:name] if args.key?(:name) @priority = args[:priority] if args.key?(:priority) @producer_extension = args[:producer_extension] if args.key?(:producer_extension) @producer_metadata = args[:producer_metadata] if args.key?(:producer_metadata) @target = args[:target] if args.key?(:target) @update_time = args[:update_time] if args.key?(:update_time) end |