Class: Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchConditionStringMatch
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchConditionStringMatch
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
Specifies matching logic for string values.
Instance Attribute Summary collapse
-
#contains ⇒ String
Optional.
-
#exact ⇒ String
Optional.
-
#ignore_case ⇒ Boolean
(also: #ignore_case?)
Optional.
-
#prefix ⇒ String
Optional.
-
#suffix ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExtensionBindingMatchConditionStringMatch
constructor
A new instance of ExtensionBindingMatchConditionStringMatch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExtensionBindingMatchConditionStringMatch
Returns a new instance of ExtensionBindingMatchConditionStringMatch.
924 925 926 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 924 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contains ⇒ String
Optional. The input string must have the substring specified here. Note: empty
contains match is not allowed, please use regex instead. Examples: * abc
matches the value xyz.abc.def
Corresponds to the JSON property contains
895 896 897 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 895 def contains @contains end |
#exact ⇒ String
Optional. The input string must match exactly the string specified here.
Examples: * abc only matches the value abc.
Corresponds to the JSON property exact
901 902 903 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 901 def exact @exact end |
#ignore_case ⇒ Boolean Also known as: ignore_case?
Optional. If true, indicates the exact/prefix/suffix/contains matching should
be case insensitive. For example, the matcher data will match both input
string Data and data if set to true.
Corresponds to the JSON property ignoreCase
908 909 910 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 908 def ignore_case @ignore_case end |
#prefix ⇒ String
Optional. The input string must have the prefix specified here. Note: empty
prefix is not allowed. Examples: * abc matches the value abc.xyz
Corresponds to the JSON property prefix
915 916 917 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 915 def prefix @prefix end |
#suffix ⇒ String
Optional. The input string must have the suffix specified here. Note: empty
prefix is not allowed, please use regex instead. Examples: * abc matches
the value xyz.abc
Corresponds to the JSON property suffix
922 923 924 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 922 def suffix @suffix end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
929 930 931 932 933 934 935 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 929 def update!(**args) @contains = args[:contains] if args.key?(:contains) @exact = args[:exact] if args.key?(:exact) @ignore_case = args[:ignore_case] if args.key?(:ignore_case) @prefix = args[:prefix] if args.key?(:prefix) @suffix = args[:suffix] if args.key?(:suffix) end |