Class: Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchConditionToDestination
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchConditionToDestination
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
Describes properties of a single destination.
Instance Attribute Summary collapse
-
#header_set ⇒ Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchConditionToDestinationHeaderSet
Describes a set of HTTP headers to match against.
-
#hosts ⇒ Array<Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchConditionStringMatch>
Optional.
-
#paths ⇒ Array<Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchConditionStringMatch>
Optional.
-
#resources ⇒ Array<Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchConditionStringMatch>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExtensionBindingMatchConditionToDestination
constructor
A new instance of ExtensionBindingMatchConditionToDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExtensionBindingMatchConditionToDestination
Returns a new instance of ExtensionBindingMatchConditionToDestination.
995 996 997 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 995 def initialize(**args) update!(**args) end |
Instance Attribute Details
#header_set ⇒ Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchConditionToDestinationHeaderSet
Describes a set of HTTP headers to match against.
Corresponds to the JSON property headerSet
970 971 972 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 970 def header_set @header_set end |
#hosts ⇒ Array<Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchConditionStringMatch>
Optional. A list of HTTP Hosts to match against. Limited to 10 hosts. If not
specified, any host is allowed. If specified, a match occurs if any of the
hosts matches the host value in the request.
Corresponds to the JSON property hosts
977 978 979 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 977 def hosts @hosts end |
#paths ⇒ Array<Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchConditionStringMatch>
Optional. A list of paths to match against. Limited to 10 paths. If not
specified, any path is allowed. Note that this path match includes the query
parameters. For gRPC services, this should be a fully-qualified name of the
form /package.service/method.
Corresponds to the JSON property paths
985 986 987 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 985 def paths @paths end |
#resources ⇒ Array<Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchConditionStringMatch>
Optional. A list of non-empty strings whose value is matched against the
resource value. If not specified, any resource is allowed. If specified, a
match occurs if any of the resources matches the resource value in the request.
Limited to 5 resources.
Corresponds to the JSON property resources
993 994 995 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 993 def resources @resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1000 1001 1002 1003 1004 1005 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1000 def update!(**args) @header_set = args[:header_set] if args.key?(:header_set) @hosts = args[:hosts] if args.key?(:hosts) @paths = args[:paths] if args.key?(:paths) @resources = args[:resources] if args.key?(:resources) end |