Class: Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchConditionToDestinationHeaderSet
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchConditionToDestinationHeaderSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
Describes a set of HTTP headers to match against.
Instance Attribute Summary collapse
-
#headers ⇒ Array<Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchConditionHeaderMatch>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExtensionBindingMatchConditionToDestinationHeaderSet
constructor
A new instance of ExtensionBindingMatchConditionToDestinationHeaderSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExtensionBindingMatchConditionToDestinationHeaderSet
Returns a new instance of ExtensionBindingMatchConditionToDestinationHeaderSet.
1019 1020 1021 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1019 def initialize(**args) update!(**args) end |
Instance Attribute Details
#headers ⇒ Array<Google::Apis::NetworkservicesV1beta1::ExtensionBindingMatchConditionHeaderMatch>
Required. A list of headers to match against in http header. If multiple
header matches are provided, they will be evaluated as an AND, i.e. all header
matches must match for the request to match.
Corresponds to the JSON property headers
1017 1018 1019 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1017 def headers @headers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1024 1025 1026 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1024 def update!(**args) @headers = args[:headers] if args.key?(:headers) end |