Class: Google::Apis::NetworkservicesV1beta1::ExtensionBindingTarget
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::ExtensionBindingTarget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
Specifies a list of targets to which this ExtensionBinding should attach.
Instance Attribute Summary collapse
-
#resources ⇒ Array<String>
Optional.
-
#scope ⇒ Google::Apis::NetworkservicesV1beta1::ExtensionBindingTargetScope
Specifies the scope of resources to which this binding should attach.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExtensionBindingTarget
constructor
A new instance of ExtensionBindingTarget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExtensionBindingTarget
Returns a new instance of ExtensionBindingTarget.
1048 1049 1050 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1048 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resources ⇒ Array<String>
Optional. The reference to the target resource, to which this binding should
attach. Exactly one of resources or scope must be set. For Agent Gateway,
this would be the full resource name, in the format: projects/project/
locations/location/agentGateways/agent_gateway. For AI App, this would be
the full resource name, in the format: `projects/`project`/locations/`location`
/applications/`application.
Corresponds to the JSON property resources
1041 1042 1043 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1041 def resources @resources end |
#scope ⇒ Google::Apis::NetworkservicesV1beta1::ExtensionBindingTargetScope
Specifies the scope of resources to which this binding should attach.
Corresponds to the JSON property scope
1046 1047 1048 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1046 def scope @scope end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1053 1054 1055 1056 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1053 def update!(**args) @resources = args[:resources] if args.key?(:resources) @scope = args[:scope] if args.key?(:scope) end |