Class: Google::Apis::NetworkservicesV1beta1::Gateway

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Gateway represents the configuration for a proxy, typically a load balancer. It captures the ip:port over which the services are exposed by the proxy, along with any policy configurations. Routes have reference to to Gateways to dictate how requests should be routed by this Gateway.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Gateway

Returns a new instance of Gateway.



970
971
972
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 970

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressesArray<String>

Optional. Zero or one IPv4 or IPv6 address on which the Gateway will receive the traffic. When no address is provided, an IP from the subnetwork is allocated This field only applies to gateways of type 'SECURE_WEB_GATEWAY'. Gateways of type 'OPEN_MESH' listen on 0.0.0.0 for IPv4 and :: for IPv6. Corresponds to the JSON property addresses

Returns:

  • (Array<String>)


842
843
844
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 842

def addresses
  @addresses
end

#all_portsBoolean Also known as: all_ports?

Optional. If true, the Gateway will listen on all ports. This is mutually exclusive with the ports field. This field only applies to gateways of type ' SECURE_WEB_GATEWAY'. Corresponds to the JSON property allPorts

Returns:

  • (Boolean)


849
850
851
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 849

def all_ports
  @all_ports
end

#allow_global_accessBoolean Also known as: allow_global_access?

Optional. If true, the gateway will allow traffic from clients outside of the region where the gateway is located. This field is configurable only for gateways of type SECURE_WEB_GATEWAY. Corresponds to the JSON property allowGlobalAccess

Returns:

  • (Boolean)


857
858
859
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 857

def allow_global_access
  @allow_global_access
end

#certificate_urlsArray<String>

Optional. A fully-qualified Certificates URL reference. The proxy presents a Certificate (selected based on SNI) when establishing a TLS connection. This feature only applies to gateways of type 'SECURE_WEB_GATEWAY'. Corresponds to the JSON property certificateUrls

Returns:

  • (Array<String>)


865
866
867
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 865

def certificate_urls
  @certificate_urls
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


870
871
872
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 870

def create_time
  @create_time
end

#descriptionString

Optional. A free-text description of the resource. Max length 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


875
876
877
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 875

def description
  @description
end

#envoy_headersString

Optional. Determines if envoy will insert internal debug headers into upstream requests. Other Envoy headers may still be injected. By default, envoy will not insert any debug headers. Corresponds to the JSON property envoyHeaders

Returns:

  • (String)


882
883
884
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 882

def envoy_headers
  @envoy_headers
end

#gateway_security_policyString

Optional. A fully-qualified GatewaySecurityPolicy URL reference. Defines how a server should apply security policy to inbound (VM to Proxy) initiated connections. For example: projects/*/locations/*/gatewaySecurityPolicies/swg- policy. This policy is specific to gateways of type 'SECURE_WEB_GATEWAY'. Corresponds to the JSON property gatewaySecurityPolicy

Returns:

  • (String)


890
891
892
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 890

def gateway_security_policy
  @gateway_security_policy
end

#ip_versionString

Optional. The IP Version that will be used by this gateway. Valid options are IPV4 or IPV6. Default is IPV4. Corresponds to the JSON property ipVersion

Returns:

  • (String)


896
897
898
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 896

def ip_version
  @ip_version
end

#labelsHash<String,String>

Optional. Set of label tags associated with the Gateway resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


901
902
903
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 901

def labels
  @labels
end

#nameString

Identifier. Name of the Gateway resource. It matches pattern projects/*/ locations/*/gateways/. Corresponds to the JSON property name

Returns:

  • (String)


907
908
909
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 907

def name
  @name
end

#networkString

Optional. The relative resource name identifying the VPC network that is using this configuration. For example: projects/*/global/networks/network-1. Currently, this field is specific to gateways of type 'SECURE_WEB_GATEWAY'. Corresponds to the JSON property network

Returns:

  • (String)


914
915
916
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 914

def network
  @network
end

#portsArray<Fixnum>

Required. One or more port numbers (1-65535), on which the Gateway will receive traffic. The proxy binds to the specified ports. Gateways of type ' SECURE_WEB_GATEWAY' are limited to 5 ports. Gateways of type 'OPEN_MESH' listen on 0.0.0.0 for IPv4 and :: for IPv6 and support multiple ports. Corresponds to the JSON property ports

Returns:

  • (Array<Fixnum>)


922
923
924
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 922

def ports
  @ports
end

#routing_modeString

Optional. The routing mode of the Gateway. This field is configurable only for gateways of type SECURE_WEB_GATEWAY. This field is required for gateways of type SECURE_WEB_GATEWAY. Corresponds to the JSON property routingMode

Returns:

  • (String)


929
930
931
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 929

def routing_mode
  @routing_mode
end

#scopeString

Optional. Scope determines how configuration across multiple Gateway instances are merged. The configuration for multiple Gateway instances with the same scope will be merged as presented as a single configuration to the proxy/load balancer. Max length 64 characters. Scope should start with a letter and can only have letters, numbers, hyphens. Corresponds to the JSON property scope

Returns:

  • (String)


938
939
940
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 938

def scope
  @scope
end

Output only. Server-defined URL of this resource Corresponds to the JSON property selfLink

Returns:

  • (String)


943
944
945
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 943

def self_link
  @self_link
end

#server_tls_policyString

Optional. A fully-qualified ServerTLSPolicy URL reference. Specifies how TLS traffic is terminated. If empty, TLS termination is disabled. Corresponds to the JSON property serverTlsPolicy

Returns:

  • (String)


949
950
951
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 949

def server_tls_policy
  @server_tls_policy
end

#subnetworkString

Optional. The relative resource name identifying the subnetwork in which this SWG is allocated. For example: projects/*/regions/us-central1/subnetworks/ network-1 Currently, this field is specific to gateways of type ' SECURE_WEB_GATEWAY". Corresponds to the JSON property subnetwork

Returns:

  • (String)


957
958
959
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 957

def subnetwork
  @subnetwork
end

#typeString

Immutable. The type of the customer managed gateway. This field is required. If unspecified, an error is returned. Corresponds to the JSON property type

Returns:

  • (String)


963
964
965
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 963

def type
  @type
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


968
969
970
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 968

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 975

def update!(**args)
  @addresses = args[:addresses] if args.key?(:addresses)
  @all_ports = args[:all_ports] if args.key?(:all_ports)
  @allow_global_access = args[:allow_global_access] if args.key?(:allow_global_access)
  @certificate_urls = args[:certificate_urls] if args.key?(:certificate_urls)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @envoy_headers = args[:envoy_headers] if args.key?(:envoy_headers)
  @gateway_security_policy = args[:gateway_security_policy] if args.key?(:gateway_security_policy)
  @ip_version = args[:ip_version] if args.key?(:ip_version)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @ports = args[:ports] if args.key?(:ports)
  @routing_mode = args[:routing_mode] if args.key?(:routing_mode)
  @scope = args[:scope] if args.key?(:scope)
  @self_link = args[:self_link] if args.key?(:self_link)
  @server_tls_policy = args[:server_tls_policy] if args.key?(:server_tls_policy)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end