Class: Google::Apis::NetworkservicesV1beta1::GrpcRoute
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::GrpcRoute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
GrpcRoute is the resource defining how gRPC traffic routed by a Mesh or Gateway resource is routed.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#gateways ⇒ Array<String>
Optional.
-
#hostnames ⇒ Array<String>
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#meshes ⇒ Array<String>
Optional.
-
#name ⇒ String
Identifier.
-
#rules ⇒ Array<Google::Apis::NetworkservicesV1beta1::GrpcRouteRouteRule>
Required.
-
#self_link ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrpcRoute
constructor
A new instance of GrpcRoute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrpcRoute
Returns a new instance of GrpcRoute.
1105 1106 1107 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1105 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
1033 1034 1035 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1033 def create_time @create_time end |
#description ⇒ String
Optional. A free-text description of the resource. Max length 1024 characters.
Corresponds to the JSON property description
1038 1039 1040 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1038 def description @description end |
#gateways ⇒ Array<String>
Optional. Gateways defines a list of gateways this GrpcRoute is attached to,
as one of the routing rules to route the requests served by the gateway. Each
gateway reference should match the pattern: projects/*/locations/*/gateways/
Corresponds to the JSON property gateways
1045 1046 1047 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1045 def gateways @gateways end |
#hostnames ⇒ Array<String>
Required. Service hostnames with an optional port for which this route
describes traffic. Format: [:] Hostname is the fully qualified domain name of
a network host. This matches the RFC 1123 definition of a hostname with 2
notable exceptions: - IPs are not allowed. - A hostname may be prefixed with a
wildcard label (*.). The wildcard label must appear by itself as the first
label. Hostname can be "precise" which is a domain name without the
terminating dot of a network host (e.g. foo.example.com) or "wildcard",
which is a domain name prefixed with a single wildcard label (e.g. *.example.
com). Note that as per RFC1035 and RFC1123, a label must consist of lower
case alphanumeric characters or '-', and must start and end with an
alphanumeric character. No other punctuation is allowed. The routes associated
with a Mesh or Gateway must have unique hostnames. If you attempt to attach
multiple routes with conflicting hostnames, the configuration will be rejected.
For example, while it is acceptable for routes for the hostnames *.foo.bar.
com and *.bar.com to be associated with the same route, it is not possible
to associate two routes both with *.bar.com or both with bar.com. If a
port is specified, then gRPC clients must use the channel URI with the port to
match this rule (i.e. "xds:///service:123"), otherwise they must supply the
URI without a port (i.e. "xds:///service").
Corresponds to the JSON property hostnames
1068 1069 1070 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1068 def hostnames @hostnames end |
#labels ⇒ Hash<String,String>
Optional. Set of label tags associated with the GrpcRoute resource.
Corresponds to the JSON property labels
1073 1074 1075 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1073 def labels @labels end |
#meshes ⇒ Array<String>
Optional. Meshes defines a list of meshes this GrpcRoute is attached to, as
one of the routing rules to route the requests served by the mesh. Each mesh
reference should match the pattern: projects/*/locations/*/meshes/
Corresponds to the JSON property meshes
1080 1081 1082 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1080 def meshes @meshes end |
#name ⇒ String
Identifier. Name of the GrpcRoute resource. It matches pattern projects/*/
locations/*/grpcRoutes/
Corresponds to the JSON property name
1086 1087 1088 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1086 def name @name end |
#rules ⇒ Array<Google::Apis::NetworkservicesV1beta1::GrpcRouteRouteRule>
Required. A list of detailed rules defining how to route traffic. Within a
single GrpcRoute, the GrpcRoute.RouteAction associated with the first matching
GrpcRoute.RouteRule will be executed. At least one rule must be supplied.
Corresponds to the JSON property rules
1093 1094 1095 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1093 def rules @rules end |
#self_link ⇒ String
Output only. Server-defined URL of this resource
Corresponds to the JSON property selfLink
1098 1099 1100 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1098 def self_link @self_link end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
1103 1104 1105 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1103 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1110 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @gateways = args[:gateways] if args.key?(:gateways) @hostnames = args[:hostnames] if args.key?(:hostnames) @labels = args[:labels] if args.key?(:labels) @meshes = args[:meshes] if args.key?(:meshes) @name = args[:name] if args.key?(:name) @rules = args[:rules] if args.key?(:rules) @self_link = args[:self_link] if args.key?(:self_link) @update_time = args[:update_time] if args.key?(:update_time) end |