Class: Google::Apis::NetworkservicesV1beta1::GrpcRouteRouteRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Describes how to route traffic.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrpcRouteRouteRule

Returns a new instance of GrpcRouteRouteRule.



1459
1460
1461
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1459

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionGoogle::Apis::NetworkservicesV1beta1::GrpcRouteRouteAction

Specifies how to route matched traffic. Corresponds to the JSON property action



1449
1450
1451
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1449

def action
  @action
end

#matchesArray<Google::Apis::NetworkservicesV1beta1::GrpcRouteRouteMatch>

Optional. Matches define conditions used for matching the rule against incoming gRPC requests. Each match is independent, i.e. this rule will be matched if ANY one of the matches is satisfied. If no matches field is specified, this rule will unconditionally match traffic. Corresponds to the JSON property matches



1457
1458
1459
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1457

def matches
  @matches
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1464
1465
1466
1467
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1464

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @matches = args[:matches] if args.key?(:matches)
end