Class: Google::Apis::NetworkservicesV1beta1::HttpRoute
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::HttpRoute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
HttpRoute is the resource defining how HTTP traffic should be routed by a Mesh or Gateway resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#gateways ⇒ Array<String>
Optional.
-
#hostnames ⇒ Array<String>
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#meshes ⇒ Array<String>
Optional.
-
#name ⇒ String
Identifier.
-
#rules ⇒ Array<Google::Apis::NetworkservicesV1beta1::HttpRouteRouteRule>
Required.
-
#self_link ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRoute
constructor
A new instance of HttpRoute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRoute
Returns a new instance of HttpRoute.
1591 1592 1593 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1591 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
1521 1522 1523 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1521 def create_time @create_time end |
#description ⇒ String
Optional. A free-text description of the resource. Max length 1024 characters.
Corresponds to the JSON property description
1526 1527 1528 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1526 def description @description end |
#gateways ⇒ Array<String>
Optional. Gateways defines a list of gateways this HttpRoute is attached to,
as one of the routing rules to route the requests served by the gateway. Each
gateway reference should match the pattern: projects/*/locations/*/gateways/
Corresponds to the JSON property gateways
1533 1534 1535 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1533 def gateways @gateways end |
#hostnames ⇒ Array<String>
Required. Hostnames define a set of hosts that should match against the HTTP
host header to select a HttpRoute to process the request. Hostname is the
fully qualified domain name of a network host, as defined by RFC 1123 with the
exception that: - IPs are not allowed. - A hostname may be prefixed with a
wildcard label (*.). The wildcard label must appear by itself as the first
label. Hostname can be "precise" which is a domain name without the
terminating dot of a network host (e.g. foo.example.com) or "wildcard",
which is a domain name prefixed with a single wildcard label (e.g. *.example.
com). Note that as per RFC1035 and RFC1123, a label must consist of lower
case alphanumeric characters or '-', and must start and end with an
alphanumeric character. No other punctuation is allowed. The routes associated
with a Mesh or Gateways must have unique hostnames. If you attempt to attach
multiple routes with conflicting hostnames, the configuration will be rejected.
For example, while it is acceptable for routes for the hostnames *.foo.bar.
com and *.bar.com to be associated with the same Mesh (or Gateways under
the same scope), it is not possible to associate two routes both with *.bar.
com or both with bar.com.
Corresponds to the JSON property hostnames
1554 1555 1556 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1554 def hostnames @hostnames end |
#labels ⇒ Hash<String,String>
Optional. Set of label tags associated with the HttpRoute resource.
Corresponds to the JSON property labels
1559 1560 1561 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1559 def labels @labels end |
#meshes ⇒ Array<String>
Optional. Meshes defines a list of meshes this HttpRoute is attached to, as
one of the routing rules to route the requests served by the mesh. Each mesh
reference should match the pattern: projects/*/locations/*/meshes/ The
attached Mesh should be of a type SIDECAR
Corresponds to the JSON property meshes
1567 1568 1569 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1567 def meshes @meshes end |
#name ⇒ String
Identifier. Name of the HttpRoute resource. It matches pattern projects/*/
locations/*/httpRoutes/http_route_name>.
Corresponds to the JSON property name
1573 1574 1575 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1573 def name @name end |
#rules ⇒ Array<Google::Apis::NetworkservicesV1beta1::HttpRouteRouteRule>
Required. Rules that define how traffic is routed and handled. Rules will be
matched sequentially based on the RouteMatch specified for the rule.
Corresponds to the JSON property rules
1579 1580 1581 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1579 def rules @rules end |
#self_link ⇒ String
Output only. Server-defined URL of this resource
Corresponds to the JSON property selfLink
1584 1585 1586 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1584 def self_link @self_link end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
1589 1590 1591 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1589 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1596 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @gateways = args[:gateways] if args.key?(:gateways) @hostnames = args[:hostnames] if args.key?(:hostnames) @labels = args[:labels] if args.key?(:labels) @meshes = args[:meshes] if args.key?(:meshes) @name = args[:name] if args.key?(:name) @rules = args[:rules] if args.key?(:rules) @self_link = args[:self_link] if args.key?(:self_link) @update_time = args[:update_time] if args.key?(:update_time) end |