Class: Google::Apis::NetworkservicesV1beta1::HttpRoute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

HttpRoute is the resource defining how HTTP traffic should be routed by a Mesh or Gateway resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpRoute

Returns a new instance of HttpRoute.



1293
1294
1295
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1293

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1223
1224
1225
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1223

def create_time
  @create_time
end

#descriptionString

Optional. A free-text description of the resource. Max length 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


1228
1229
1230
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1228

def description
  @description
end

#gatewaysArray<String>

Optional. Gateways defines a list of gateways this HttpRoute is attached to, as one of the routing rules to route the requests served by the gateway. Each gateway reference should match the pattern: projects/*/locations/*/gateways/ Corresponds to the JSON property gateways

Returns:

  • (Array<String>)


1235
1236
1237
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1235

def gateways
  @gateways
end

#hostnamesArray<String>

Required. Hostnames define a set of hosts that should match against the HTTP host header to select a HttpRoute to process the request. Hostname is the fully qualified domain name of a network host, as defined by RFC 1123 with the exception that: - IPs are not allowed. - A hostname may be prefixed with a wildcard label (*.). The wildcard label must appear by itself as the first label. Hostname can be "precise" which is a domain name without the terminating dot of a network host (e.g. foo.example.com) or "wildcard", which is a domain name prefixed with a single wildcard label (e.g. *.example. com). Note that as per RFC1035 and RFC1123, a label must consist of lower case alphanumeric characters or '-', and must start and end with an alphanumeric character. No other punctuation is allowed. The routes associated with a Mesh or Gateways must have unique hostnames. If you attempt to attach multiple routes with conflicting hostnames, the configuration will be rejected. For example, while it is acceptable for routes for the hostnames *.foo.bar. com and *.bar.com to be associated with the same Mesh (or Gateways under the same scope), it is not possible to associate two routes both with *.bar. com or both with bar.com. Corresponds to the JSON property hostnames

Returns:

  • (Array<String>)


1256
1257
1258
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1256

def hostnames
  @hostnames
end

#labelsHash<String,String>

Optional. Set of label tags associated with the HttpRoute resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1261
1262
1263
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1261

def labels
  @labels
end

#meshesArray<String>

Optional. Meshes defines a list of meshes this HttpRoute is attached to, as one of the routing rules to route the requests served by the mesh. Each mesh reference should match the pattern: projects/*/locations/*/meshes/ The attached Mesh should be of a type SIDECAR Corresponds to the JSON property meshes

Returns:

  • (Array<String>)


1269
1270
1271
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1269

def meshes
  @meshes
end

#nameString

Identifier. Name of the HttpRoute resource. It matches pattern projects/*/ locations/*/httpRoutes/http_route_name>. Corresponds to the JSON property name

Returns:

  • (String)


1275
1276
1277
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1275

def name
  @name
end

#rulesArray<Google::Apis::NetworkservicesV1beta1::HttpRouteRouteRule>

Required. Rules that define how traffic is routed and handled. Rules will be matched sequentially based on the RouteMatch specified for the rule. Corresponds to the JSON property rules



1281
1282
1283
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1281

def rules
  @rules
end

Output only. Server-defined URL of this resource Corresponds to the JSON property selfLink

Returns:

  • (String)


1286
1287
1288
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1286

def self_link
  @self_link
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1291
1292
1293
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1291

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1298

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @gateways = args[:gateways] if args.key?(:gateways)
  @hostnames = args[:hostnames] if args.key?(:hostnames)
  @labels = args[:labels] if args.key?(:labels)
  @meshes = args[:meshes] if args.key?(:meshes)
  @name = args[:name] if args.key?(:name)
  @rules = args[:rules] if args.key?(:rules)
  @self_link = args[:self_link] if args.key?(:self_link)
  @update_time = args[:update_time] if args.key?(:update_time)
end