Class: Google::Apis::NetworkservicesV1beta1::HttpRouteDestination
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::HttpRouteDestination
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
Specifications of a destination to which the request should be routed to.
Instance Attribute Summary collapse
-
#request_header_modifier ⇒ Google::Apis::NetworkservicesV1beta1::HttpRouteHeaderModifier
The specification for modifying HTTP header in HTTP request and HTTP response.
-
#response_header_modifier ⇒ Google::Apis::NetworkservicesV1beta1::HttpRouteHeaderModifier
The specification for modifying HTTP header in HTTP request and HTTP response.
-
#service_name ⇒ String
The URL of a BackendService to route traffic to.
-
#weight ⇒ Fixnum
Specifies the proportion of requests forwarded to the backend referenced by the serviceName field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRouteDestination
constructor
A new instance of HttpRouteDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRouteDestination
Returns a new instance of HttpRouteDestination.
2219 2220 2221 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2219 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_header_modifier ⇒ Google::Apis::NetworkservicesV1beta1::HttpRouteHeaderModifier
The specification for modifying HTTP header in HTTP request and HTTP response.
Corresponds to the JSON property requestHeaderModifier
2194 2195 2196 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2194 def request_header_modifier @request_header_modifier end |
#response_header_modifier ⇒ Google::Apis::NetworkservicesV1beta1::HttpRouteHeaderModifier
The specification for modifying HTTP header in HTTP request and HTTP response.
Corresponds to the JSON property responseHeaderModifier
2199 2200 2201 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2199 def response_header_modifier @response_header_modifier end |
#service_name ⇒ String
The URL of a BackendService to route traffic to.
Corresponds to the JSON property serviceName
2204 2205 2206 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2204 def service_name @service_name end |
#weight ⇒ Fixnum
Specifies the proportion of requests forwarded to the backend referenced by
the serviceName field. This is computed as: - weight/Sum(weights in this
destination list). For non-zero values, there may be some epsilon from the
exact proportion defined here depending on the precision an implementation
supports. If only one serviceName is specified and it has a weight greater
than 0, 100% of the traffic is forwarded to that backend. If weights are
specified for any one service name, they need to be specified for all of them.
If weights are unspecified for all services, then, traffic is distributed in
equal proportions to all of them.
Corresponds to the JSON property weight
2217 2218 2219 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2217 def weight @weight end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2224 2225 2226 2227 2228 2229 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2224 def update!(**args) @request_header_modifier = args[:request_header_modifier] if args.key?(:request_header_modifier) @response_header_modifier = args[:response_header_modifier] if args.key?(:response_header_modifier) @service_name = args[:service_name] if args.key?(:service_name) @weight = args[:weight] if args.key?(:weight) end |