Class: Google::Apis::NetworkservicesV1beta1::HttpRouteHeaderMatch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Specifies how to select a route rule based on HTTP request headers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpRouteHeaderMatch

Returns a new instance of HttpRouteHeaderMatch.



1863
1864
1865
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1863

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exact_matchString

The value of the header should match exactly the content of exact_match. Corresponds to the JSON property exactMatch

Returns:

  • (String)


1820
1821
1822
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1820

def exact_match
  @exact_match
end

#headerString

The name of the HTTP header to match against. Corresponds to the JSON property header

Returns:

  • (String)


1825
1826
1827
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1825

def header
  @header
end

#invert_matchBoolean Also known as: invert_match?

If specified, the match result will be inverted before checking. Default value is set to false. Corresponds to the JSON property invertMatch

Returns:

  • (Boolean)


1831
1832
1833
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1831

def invert_match
  @invert_match
end

#prefix_matchString

The value of the header must start with the contents of prefix_match. Corresponds to the JSON property prefixMatch

Returns:

  • (String)


1837
1838
1839
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1837

def prefix_match
  @prefix_match
end

#present_matchBoolean Also known as: present_match?

A header with header_name must exist. The match takes place whether or not the header has a value. Corresponds to the JSON property presentMatch

Returns:

  • (Boolean)


1843
1844
1845
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1843

def present_match
  @present_match
end

#range_matchGoogle::Apis::NetworkservicesV1beta1::HttpRouteHeaderMatchIntegerRange

Represents an integer value range. Corresponds to the JSON property rangeMatch



1849
1850
1851
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1849

def range_match
  @range_match
end

#regex_matchString

The value of the header must match the regular expression specified in regex_match. For regular expression grammar, please see: https://github.com/ google/re2/wiki/Syntax Corresponds to the JSON property regexMatch

Returns:

  • (String)


1856
1857
1858
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1856

def regex_match
  @regex_match
end

#suffix_matchString

The value of the header must end with the contents of suffix_match. Corresponds to the JSON property suffixMatch

Returns:

  • (String)


1861
1862
1863
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1861

def suffix_match
  @suffix_match
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1868

def update!(**args)
  @exact_match = args[:exact_match] if args.key?(:exact_match)
  @header = args[:header] if args.key?(:header)
  @invert_match = args[:invert_match] if args.key?(:invert_match)
  @prefix_match = args[:prefix_match] if args.key?(:prefix_match)
  @present_match = args[:present_match] if args.key?(:present_match)
  @range_match = args[:range_match] if args.key?(:range_match)
  @regex_match = args[:regex_match] if args.key?(:regex_match)
  @suffix_match = args[:suffix_match] if args.key?(:suffix_match)
end