Class: Google::Apis::NetworkservicesV1beta1::HttpRouteHeaderMatch
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::HttpRouteHeaderMatch
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
Specifies how to select a route rule based on HTTP request headers.
Instance Attribute Summary collapse
-
#exact_match ⇒ String
The value of the header should match exactly the content of exact_match.
-
#header ⇒ String
The name of the HTTP header to match against.
-
#invert_match ⇒ Boolean
(also: #invert_match?)
If specified, the match result will be inverted before checking.
-
#prefix_match ⇒ String
The value of the header must start with the contents of prefix_match.
-
#present_match ⇒ Boolean
(also: #present_match?)
A header with header_name must exist.
-
#range_match ⇒ Google::Apis::NetworkservicesV1beta1::HttpRouteHeaderMatchIntegerRange
Represents an integer value range.
-
#regex_match ⇒ String
The value of the header must match the regular expression specified in regex_match.
-
#suffix_match ⇒ String
The value of the header must end with the contents of suffix_match.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRouteHeaderMatch
constructor
A new instance of HttpRouteHeaderMatch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRouteHeaderMatch
Returns a new instance of HttpRouteHeaderMatch.
1565 1566 1567 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1565 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exact_match ⇒ String
The value of the header should match exactly the content of exact_match.
Corresponds to the JSON property exactMatch
1522 1523 1524 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1522 def exact_match @exact_match end |
#header ⇒ String
The name of the HTTP header to match against.
Corresponds to the JSON property header
1527 1528 1529 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1527 def header @header end |
#invert_match ⇒ Boolean Also known as: invert_match?
If specified, the match result will be inverted before checking. Default value
is set to false.
Corresponds to the JSON property invertMatch
1533 1534 1535 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1533 def invert_match @invert_match end |
#prefix_match ⇒ String
The value of the header must start with the contents of prefix_match.
Corresponds to the JSON property prefixMatch
1539 1540 1541 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1539 def prefix_match @prefix_match end |
#present_match ⇒ Boolean Also known as: present_match?
A header with header_name must exist. The match takes place whether or not the
header has a value.
Corresponds to the JSON property presentMatch
1545 1546 1547 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1545 def present_match @present_match end |
#range_match ⇒ Google::Apis::NetworkservicesV1beta1::HttpRouteHeaderMatchIntegerRange
Represents an integer value range.
Corresponds to the JSON property rangeMatch
1551 1552 1553 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1551 def range_match @range_match end |
#regex_match ⇒ String
The value of the header must match the regular expression specified in
regex_match. For regular expression grammar, please see: https://github.com/
google/re2/wiki/Syntax
Corresponds to the JSON property regexMatch
1558 1559 1560 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1558 def regex_match @regex_match end |
#suffix_match ⇒ String
The value of the header must end with the contents of suffix_match.
Corresponds to the JSON property suffixMatch
1563 1564 1565 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1563 def suffix_match @suffix_match end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 1570 def update!(**args) @exact_match = args[:exact_match] if args.key?(:exact_match) @header = args[:header] if args.key?(:header) @invert_match = args[:invert_match] if args.key?(:invert_match) @prefix_match = args[:prefix_match] if args.key?(:prefix_match) @present_match = args[:present_match] if args.key?(:present_match) @range_match = args[:range_match] if args.key?(:range_match) @regex_match = args[:regex_match] if args.key?(:regex_match) @suffix_match = args[:suffix_match] if args.key?(:suffix_match) end |