Class: Google::Apis::NetworkservicesV1beta1::HttpRouteRouteMatch
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::HttpRouteRouteMatch
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
RouteMatch defines specifications used to match requests. If multiple match types are set, this RouteMatch will match if ALL type of matches are matched.
Instance Attribute Summary collapse
-
#full_path_match ⇒ String
The HTTP request path value should exactly match this value.
-
#headers ⇒ Array<Google::Apis::NetworkservicesV1beta1::HttpRouteHeaderMatch>
Specifies a list of HTTP request headers to match against.
-
#ignore_case ⇒ Boolean
(also: #ignore_case?)
Specifies if prefix_match and full_path_match matches are case sensitive.
-
#prefix_match ⇒ String
The HTTP request path value must begin with specified prefix_match.
-
#query_parameters ⇒ Array<Google::Apis::NetworkservicesV1beta1::HttpRouteQueryParameterMatch>
Specifies a list of query parameters to match against.
-
#regex_match ⇒ String
The HTTP request path value must satisfy the regular expression specified by regex_match after removing any query parameters and anchor supplied with the original URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRouteRouteMatch
constructor
A new instance of HttpRouteRouteMatch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRouteRouteMatch
Returns a new instance of HttpRouteRouteMatch.
2300 2301 2302 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2300 def initialize(**args) update!(**args) end |
Instance Attribute Details
#full_path_match ⇒ String
The HTTP request path value should exactly match this value. Only one of
full_path_match, prefix_match, or regex_match should be used.
Corresponds to the JSON property fullPathMatch
2263 2264 2265 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2263 def full_path_match @full_path_match end |
#headers ⇒ Array<Google::Apis::NetworkservicesV1beta1::HttpRouteHeaderMatch>
Specifies a list of HTTP request headers to match against. ALL of the supplied
headers must be matched.
Corresponds to the JSON property headers
2269 2270 2271 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2269 def headers @headers end |
#ignore_case ⇒ Boolean Also known as: ignore_case?
Specifies if prefix_match and full_path_match matches are case sensitive. The
default value is false.
Corresponds to the JSON property ignoreCase
2275 2276 2277 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2275 def ignore_case @ignore_case end |
#prefix_match ⇒ String
The HTTP request path value must begin with specified prefix_match.
prefix_match must begin with a /. Only one of full_path_match, prefix_match,
or regex_match should be used.
Corresponds to the JSON property prefixMatch
2283 2284 2285 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2283 def prefix_match @prefix_match end |
#query_parameters ⇒ Array<Google::Apis::NetworkservicesV1beta1::HttpRouteQueryParameterMatch>
Specifies a list of query parameters to match against. ALL of the query
parameters must be matched.
Corresponds to the JSON property queryParameters
2289 2290 2291 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2289 def query_parameters @query_parameters end |
#regex_match ⇒ String
The HTTP request path value must satisfy the regular expression specified by
regex_match after removing any query parameters and anchor supplied with the
original URL. For regular expression grammar, please see https://github.com/
google/re2/wiki/Syntax Only one of full_path_match, prefix_match, or
regex_match should be used.
Corresponds to the JSON property regexMatch
2298 2299 2300 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2298 def regex_match @regex_match end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2305 2306 2307 2308 2309 2310 2311 2312 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2305 def update!(**args) @full_path_match = args[:full_path_match] if args.key?(:full_path_match) @headers = args[:headers] if args.key?(:headers) @ignore_case = args[:ignore_case] if args.key?(:ignore_case) @prefix_match = args[:prefix_match] if args.key?(:prefix_match) @query_parameters = args[:query_parameters] if args.key?(:query_parameters) @regex_match = args[:regex_match] if args.key?(:regex_match) end |