Class: Google::Apis::NetworkservicesV1beta1::HttpRouteUrlRewrite
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::HttpRouteUrlRewrite
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
The specification for modifying the URL of the request, prior to forwarding the request to the destination.
Instance Attribute Summary collapse
-
#host_rewrite ⇒ String
Prior to forwarding the request to the selected destination, the requests host header is replaced by this value.
-
#path_prefix_rewrite ⇒ String
Prior to forwarding the request to the selected destination, the matching portion of the requests path is replaced by this value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRouteUrlRewrite
constructor
A new instance of HttpRouteUrlRewrite.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRouteUrlRewrite
Returns a new instance of HttpRouteUrlRewrite.
2108 2109 2110 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2108 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host_rewrite ⇒ String
Prior to forwarding the request to the selected destination, the requests host
header is replaced by this value.
Corresponds to the JSON property hostRewrite
2100 2101 2102 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2100 def host_rewrite @host_rewrite end |
#path_prefix_rewrite ⇒ String
Prior to forwarding the request to the selected destination, the matching
portion of the requests path is replaced by this value.
Corresponds to the JSON property pathPrefixRewrite
2106 2107 2108 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2106 def path_prefix_rewrite @path_prefix_rewrite end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2113 2114 2115 2116 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2113 def update!(**args) @host_rewrite = args[:host_rewrite] if args.key?(:host_rewrite) @path_prefix_rewrite = args[:path_prefix_rewrite] if args.key?(:path_prefix_rewrite) end |