Class: Google::Apis::NetworkservicesV1beta1::LbEdgeExtension
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::LbEdgeExtension
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
LbEdgeExtension is a resource that lets the extension service influence the
selection of backend services and Cloud CDN cache keys by modifying request
headers.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#extension_chains ⇒ Array<Google::Apis::NetworkservicesV1beta1::ExtensionChain>
Required.
-
#forwarding_rules ⇒ Array<String>
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#load_balancing_scheme ⇒ String
Required.
-
#name ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LbEdgeExtension
constructor
A new instance of LbEdgeExtension.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LbEdgeExtension
Returns a new instance of LbEdgeExtension.
2474 2475 2476 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2474 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
2426 2427 2428 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2426 def create_time @create_time end |
#description ⇒ String
Optional. A human-readable description of the resource.
Corresponds to the JSON property description
2431 2432 2433 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2431 def description @description end |
#extension_chains ⇒ Array<Google::Apis::NetworkservicesV1beta1::ExtensionChain>
Required. A set of ordered extension chains that contain the match conditions
and extensions to execute. Match conditions for each extension chain are
evaluated in sequence for a given request. The first extension chain that has
a condition that matches the request is executed. Any subsequent extension
chains do not execute. Limited to 5 extension chains per resource.
Corresponds to the JSON property extensionChains
2440 2441 2442 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2440 def extension_chains @extension_chains end |
#forwarding_rules ⇒ Array<String>
Required. A list of references to the forwarding rules to which this service
extension is attached. At least one forwarding rule is required. Only one
LbEdgeExtension resource can be associated with a forwarding rule.
Corresponds to the JSON property forwardingRules
2447 2448 2449 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2447 def forwarding_rules @forwarding_rules end |
#labels ⇒ Hash<String,String>
Optional. Set of labels associated with the LbEdgeExtension resource. The
format must comply with the requirements for labels for Google Cloud resources.
Corresponds to the JSON property labels
2454 2455 2456 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2454 def labels @labels end |
#load_balancing_scheme ⇒ String
Required. All forwarding rules referenced by this extension must share the
same load balancing scheme. Supported values: EXTERNAL_MANAGED.
Corresponds to the JSON property loadBalancingScheme
2460 2461 2462 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2460 def load_balancing_scheme @load_balancing_scheme end |
#name ⇒ String
Required. Identifier. Name of the LbEdgeExtension resource in the following
format: projects/project/locations/location/lbEdgeExtensions/
lb_edge_extension`.
Corresponds to the JSON propertyname`
2467 2468 2469 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2467 def name @name end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
2472 2473 2474 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2472 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2479 2480 2481 2482 2483 2484 2485 2486 2487 2488 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2479 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @extension_chains = args[:extension_chains] if args.key?(:extension_chains) @forwarding_rules = args[:forwarding_rules] if args.key?(:forwarding_rules) @labels = args[:labels] if args.key?(:labels) @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |