Class: Google::Apis::NetworkservicesV1beta1::LbEdgeExtension

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

LbEdgeExtension is a resource that lets the extension service influence the selection of backend services and Cloud CDN cache keys by modifying request headers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LbEdgeExtension

Returns a new instance of LbEdgeExtension.



2485
2486
2487
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2485

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2437
2438
2439
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2437

def create_time
  @create_time
end

#descriptionString

Optional. A human-readable description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


2442
2443
2444
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2442

def description
  @description
end

#extension_chainsArray<Google::Apis::NetworkservicesV1beta1::ExtensionChain>

Required. A set of ordered extension chains that contain the match conditions and extensions to execute. Match conditions for each extension chain are evaluated in sequence for a given request. The first extension chain that has a condition that matches the request is executed. Any subsequent extension chains do not execute. Limited to 5 extension chains per resource. Corresponds to the JSON property extensionChains



2451
2452
2453
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2451

def extension_chains
  @extension_chains
end

#forwarding_rulesArray<String>

Required. A list of references to the forwarding rules to which this service extension is attached. At least one forwarding rule is required. Only one LbEdgeExtension resource can be associated with a forwarding rule. Corresponds to the JSON property forwardingRules

Returns:

  • (Array<String>)


2458
2459
2460
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2458

def forwarding_rules
  @forwarding_rules
end

#labelsHash<String,String>

Optional. Set of labels associated with the LbEdgeExtension resource. The format must comply with the requirements for labels for Google Cloud resources. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2465
2466
2467
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2465

def labels
  @labels
end

#load_balancing_schemeString

Required. All forwarding rules referenced by this extension must share the same load balancing scheme. Supported values: EXTERNAL_MANAGED. Corresponds to the JSON property loadBalancingScheme

Returns:

  • (String)


2471
2472
2473
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2471

def load_balancing_scheme
  @load_balancing_scheme
end

#nameString

Required. Identifier. Name of the LbEdgeExtension resource in the following format: projects/project/locations/location/lbEdgeExtensions/ lb_edge_extension`. Corresponds to the JSON propertyname`

Returns:

  • (String)


2478
2479
2480
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2478

def name
  @name
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2483
2484
2485
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2483

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2490

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @extension_chains = args[:extension_chains] if args.key?(:extension_chains)
  @forwarding_rules = args[:forwarding_rules] if args.key?(:forwarding_rules)
  @labels = args[:labels] if args.key?(:labels)
  @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end