Class: Google::Apis::NetworkservicesV1beta1::LbTcpExtension

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

LbTcpExtension is a resource that allows traffic forwarding to different backend services to make allow/deny decisions on TCP connections for all L7 Load Balancers within a network. Currently only internal load-balancers are supported.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LbTcpExtension

Returns a new instance of LbTcpExtension.



2637
2638
2639
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2637

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2585
2586
2587
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2585

def create_time
  @create_time
end

#descriptionString

Optional. A human-readable description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


2590
2591
2592
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2590

def description
  @description
end

#extension_chainsArray<Google::Apis::NetworkservicesV1beta1::ExtensionChain>

Required. A set of ordered extension chains that contain the match conditions and extensions to execute. Match conditions for each extension chain are evaluated in sequence for a given request. The first extension chain that has a condition that matches the request is executed. Any subsequent extension chains do not execute. Limited to 5 extension chains per resource. Corresponds to the JSON property extensionChains



2599
2600
2601
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2599

def extension_chains
  @extension_chains
end

#labelsHash<String,String>

Optional. Set of labels associated with the LbTcpExtension resource. The format must comply with the requirements for labels for Google Cloud resources. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2606
2607
2608
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2606

def labels
  @labels
end

#load_balancing_schemeString

Required. All backend services and forwarding rules referenced by this extension must share the same load balancing scheme. Supported values: INTERNAL_MANAGED. For more information, refer to Backend services overview. Corresponds to the JSON property loadBalancingScheme

Returns:

  • (String)


2614
2615
2616
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2614

def load_balancing_scheme
  @load_balancing_scheme
end

#nameString

Required. Identifier. Name of the LbTcpExtension resource in the following format: projects/project/locations/location/LbTcpExtension/ lb_tcp_extension` Corresponds to the JSON propertyname`

Returns:

  • (String)


2621
2622
2623
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2621

def name
  @name
end

#networksArray<String>

Optional. If set, this LbTcpExtension resource applies to all ForwardingRule resources in these VPC networks. Values should be relative resource names identifying VPC networks, for example projects/*/global/ networks/network-1. Currently limited to 1 network per resource. Limited to 1 network per resource. Corresponds to the JSON property networks

Returns:

  • (Array<String>)


2630
2631
2632
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2630

def networks
  @networks
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2635
2636
2637
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2635

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2642

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @extension_chains = args[:extension_chains] if args.key?(:extension_chains)
  @labels = args[:labels] if args.key?(:labels)
  @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme)
  @name = args[:name] if args.key?(:name)
  @networks = args[:networks] if args.key?(:networks)
  @update_time = args[:update_time] if args.key?(:update_time)
end