Class: Google::Apis::NetworkservicesV1beta1::LbTcpExtension
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::LbTcpExtension
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
LbTcpExtension is a resource that allows traffic forwarding to different
backend services to make allow/deny decisions on TCP connections for all L7
Load Balancers within a network. Currently only internal load-balancers are
supported.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#extension_chains ⇒ Array<Google::Apis::NetworkservicesV1beta1::ExtensionChain>
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#load_balancing_scheme ⇒ String
Required.
-
#name ⇒ String
Required.
-
#networks ⇒ Array<String>
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LbTcpExtension
constructor
A new instance of LbTcpExtension.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LbTcpExtension
Returns a new instance of LbTcpExtension.
2347 2348 2349 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2347 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
2295 2296 2297 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2295 def create_time @create_time end |
#description ⇒ String
Optional. A human-readable description of the resource.
Corresponds to the JSON property description
2300 2301 2302 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2300 def description @description end |
#extension_chains ⇒ Array<Google::Apis::NetworkservicesV1beta1::ExtensionChain>
Required. A set of ordered extension chains that contain the match conditions
and extensions to execute. Match conditions for each extension chain are
evaluated in sequence for a given request. The first extension chain that has
a condition that matches the request is executed. Any subsequent extension
chains do not execute. Limited to 5 extension chains per resource.
Corresponds to the JSON property extensionChains
2309 2310 2311 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2309 def extension_chains @extension_chains end |
#labels ⇒ Hash<String,String>
Optional. Set of labels associated with the LbTcpExtension resource. The
format must comply with the requirements for labels for Google Cloud resources.
Corresponds to the JSON property labels
2316 2317 2318 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2316 def labels @labels end |
#load_balancing_scheme ⇒ String
Required. All backend services and forwarding rules referenced by this
extension must share the same load balancing scheme. Supported values:
INTERNAL_MANAGED. For more information, refer to Backend services overview.
Corresponds to the JSON property loadBalancingScheme
2324 2325 2326 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2324 def load_balancing_scheme @load_balancing_scheme end |
#name ⇒ String
Required. Identifier. Name of the LbTcpExtension resource in the following
format: projects/project/locations/location/LbTcpExtension/
lb_tcp_extension`
Corresponds to the JSON propertyname`
2331 2332 2333 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2331 def name @name end |
#networks ⇒ Array<String>
Optional. If set, this LbTcpExtension resource applies to all
ForwardingRule resources in these VPC networks. Values should be relative
resource names identifying VPC networks, for example projects/*/global/
networks/network-1. Currently limited to 1 network per resource. Limited to 1
network per resource.
Corresponds to the JSON property networks
2340 2341 2342 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2340 def networks @networks end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
2345 2346 2347 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2345 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2352 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @extension_chains = args[:extension_chains] if args.key?(:extension_chains) @labels = args[:labels] if args.key?(:labels) @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme) @name = args[:name] if args.key?(:name) @networks = args[:networks] if args.key?(:networks) @update_time = args[:update_time] if args.key?(:update_time) end |