Class: Google::Apis::NetworkservicesV1beta1::LbTrafficExtension

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

LbTrafficExtension is a resource that lets the extension service modify the headers and payloads of both requests and responses without impacting the choice of backend services or any other security policies associated with the backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LbTrafficExtension

Returns a new instance of LbTrafficExtension.



2440
2441
2442
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2440

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2374
2375
2376
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2374

def create_time
  @create_time
end

#descriptionString

Optional. A human-readable description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


2379
2380
2381
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2379

def description
  @description
end

#extension_chainsArray<Google::Apis::NetworkservicesV1beta1::ExtensionChain>

Required. A set of ordered extension chains that contain the match conditions and extensions to execute. Match conditions for each extension chain are evaluated in sequence for a given request. The first extension chain that has a condition that matches the request is executed. Any subsequent extension chains do not execute. Limited to 5 extension chains per resource. Corresponds to the JSON property extensionChains



2388
2389
2390
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2388

def extension_chains
  @extension_chains
end

#forwarding_rulesArray<String>

Optional. A list of references to the forwarding rules to which this service extension is attached. At least one forwarding rule is required. Only one LbTrafficExtension resource can be associated with a forwarding rule. Corresponds to the JSON property forwardingRules

Returns:

  • (Array<String>)


2395
2396
2397
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2395

def forwarding_rules
  @forwarding_rules
end

#labelsHash<String,String>

Optional. Set of labels associated with the LbTrafficExtension resource. The format must comply with the requirements for labels for Google Cloud resources. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2402
2403
2404
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2402

def labels
  @labels
end

#load_balancing_schemeString

Required. All backend services and forwarding rules referenced by this extension must share the same load balancing scheme. Supported values: INTERNAL_MANAGED and EXTERNAL_MANAGED. For more information, refer to Backend services overview. Corresponds to the JSON property loadBalancingScheme

Returns:

  • (String)


2411
2412
2413
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2411

def load_balancing_scheme
  @load_balancing_scheme
end

#metadataHash<String,Object>

Optional. The metadata provided here is included as part of the metadata_context (of type google.protobuf.Struct) in the ProcessingRequest message sent to the extension server. The metadata applies to all extensions in all extensions chains in this resource. The metadata is available under the key com.google.lb_traffic_extension.. The following variables are supported in the metadata: forwarding_rule_id - substituted with the forwarding rule' s fully qualified resource name. This field must not be set if at least one of the extension chains contains plugin extensions. Setting it results in a validation error. You can set metadata at either the resource level or the extension level. The extension level metadata is recommended because you can pass a different set of metadata through each extension to the backend. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


2426
2427
2428
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2426

def 
  @metadata
end

#nameString

Required. Identifier. Name of the LbTrafficExtension resource in the following format: projects/project/locations/location/lbTrafficExtensions/ lb_traffic_extension`. Corresponds to the JSON propertyname`

Returns:

  • (String)


2433
2434
2435
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2433

def name
  @name
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2438
2439
2440
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2438

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2445
2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2445

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @extension_chains = args[:extension_chains] if args.key?(:extension_chains)
  @forwarding_rules = args[:forwarding_rules] if args.key?(:forwarding_rules)
  @labels = args[:labels] if args.key?(:labels)
  @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end