Class: Google::Apis::NetworkservicesV1beta1::ListMeshRouteViewsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Response returned by the ListMeshRouteViews method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMeshRouteViewsResponse

Returns a new instance of ListMeshRouteViewsResponse.



2832
2833
2834
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2832

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#mesh_route_viewsArray<Google::Apis::NetworkservicesV1beta1::MeshRouteView>

List of MeshRouteView resources. Corresponds to the JSON property meshRouteViews



2817
2818
2819
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2817

def mesh_route_views
  @mesh_route_views
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2823
2824
2825
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2823

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unreachable resources. Populated when the request attempts to list all resources across all supported locations, while some locations are temporarily unavailable. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2830
2831
2832
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2830

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2837
2838
2839
2840
2841
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2837

def update!(**args)
  @mesh_route_views = args[:mesh_route_views] if args.key?(:mesh_route_views)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end