Class: Google::Apis::NetworkservicesV1beta1::ListMeshesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Response returned by the ListMeshes method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMeshesResponse

Returns a new instance of ListMeshesResponse.



3185
3186
3187
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3185

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#meshesArray<Google::Apis::NetworkservicesV1beta1::Mesh>

List of Mesh resources. Corresponds to the JSON property meshes



3169
3170
3171
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3169

def meshes
  @meshes
end

#next_page_tokenString

If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3176
3177
3178
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3176

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unreachable resources. Populated when the request opts into return_partial_success and reading across collections e.g. when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3183
3184
3185
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3183

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3190
3191
3192
3193
3194
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3190

def update!(**args)
  @meshes = args[:meshes] if args.key?(:meshes)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end