Class: Google::Apis::NetworkservicesV1beta1::ListServiceLbPoliciesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Response returned by the ListServiceLbPolicies method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListServiceLbPoliciesResponse

Returns a new instance of ListServiceLbPoliciesResponse.



3289
3290
3291
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3289

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3275
3276
3277
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3275

def next_page_token
  @next_page_token
end

#service_lb_policiesArray<Google::Apis::NetworkservicesV1beta1::ServiceLbPolicy>

List of ServiceLbPolicy resources. Corresponds to the JSON property serviceLbPolicies



3280
3281
3282
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3280

def service_lb_policies
  @service_lb_policies
end

#unreachableArray<String>

Unreachable resources. Populated when the request attempts to list all resources across all supported locations, while some locations are temporarily unavailable. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3287
3288
3289
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3287

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3294
3295
3296
3297
3298
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3294

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @service_lb_policies = args[:service_lb_policies] if args.key?(:service_lb_policies)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end