Class: Google::Apis::NetworkservicesV1beta1::ListServiceLbPoliciesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Response returned by the ListServiceLbPolicies method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListServiceLbPoliciesResponse

Returns a new instance of ListServiceLbPoliciesResponse.



2971
2972
2973
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2971

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2957
2958
2959
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2957

def next_page_token
  @next_page_token
end

#service_lb_policiesArray<Google::Apis::NetworkservicesV1beta1::ServiceLbPolicy>

List of ServiceLbPolicy resources. Corresponds to the JSON property serviceLbPolicies



2962
2963
2964
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2962

def service_lb_policies
  @service_lb_policies
end

#unreachableArray<String>

Unreachable resources. Populated when the request attempts to list all resources across all supported locations, while some locations are temporarily unavailable. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2969
2970
2971
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2969

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2976
2977
2978
2979
2980
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 2976

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @service_lb_policies = args[:service_lb_policies] if args.key?(:service_lb_policies)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end