Class: Google::Apis::NetworkservicesV1beta1::ListTlsRoutesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Response returned by the ListTlsRoutes method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListTlsRoutesResponse

Returns a new instance of ListTlsRoutesResponse.



3041
3042
3043
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3041

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3027
3028
3029
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3027

def next_page_token
  @next_page_token
end

#tls_routesArray<Google::Apis::NetworkservicesV1beta1::TlsRoute>

List of TlsRoute resources. Corresponds to the JSON property tlsRoutes



3032
3033
3034
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3032

def tls_routes
  @tls_routes
end

#unreachableArray<String>

Unreachable resources. Populated when the request opts into return_partial_success and reading across collections e.g. when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3039
3040
3041
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3039

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3046
3047
3048
3049
3050
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3046

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @tls_routes = args[:tls_routes] if args.key?(:tls_routes)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end