Class: Google::Apis::NetworkservicesV1beta1::Mesh
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::Mesh
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
Mesh represents a logical configuration grouping for workload to workload communication within a service mesh. Routes that point to mesh dictate how requests are routed within this logical mesh boundary.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#envoy_headers ⇒ String
Optional.
-
#interception_port ⇒ Fixnum
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#self_link ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Mesh
constructor
A new instance of Mesh.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Mesh
Returns a new instance of Mesh.
3760 3761 3762 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3760 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
3716 3717 3718 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3716 def create_time @create_time end |
#description ⇒ String
Optional. A free-text description of the resource. Max length 1024 characters.
Corresponds to the JSON property description
3721 3722 3723 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3721 def description @description end |
#envoy_headers ⇒ String
Optional. Determines if envoy will insert internal debug headers into upstream
requests. Other Envoy headers may still be injected. By default, envoy will
not insert any debug headers.
Corresponds to the JSON property envoyHeaders
3728 3729 3730 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3728 def envoy_headers @envoy_headers end |
#interception_port ⇒ Fixnum
Optional. If set to a valid TCP port (1-65535), instructs the SIDECAR proxy to
listen on the specified port of localhost (127.0.0.1) address. The SIDECAR
proxy will expect all traffic to be redirected to this port regardless of its
actual ip:port destination. If unset, a port '15001' is used as the
interception port. This is applicable only for sidecar proxy deployments.
Corresponds to the JSON property interceptionPort
3737 3738 3739 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3737 def interception_port @interception_port end |
#labels ⇒ Hash<String,String>
Optional. Set of label tags associated with the Mesh resource.
Corresponds to the JSON property labels
3742 3743 3744 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3742 def labels @labels end |
#name ⇒ String
Identifier. Name of the Mesh resource. It matches pattern projects/*/
locations/*/meshes/.
Corresponds to the JSON property name
3748 3749 3750 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3748 def name @name end |
#self_link ⇒ String
Output only. Server-defined URL of this resource
Corresponds to the JSON property selfLink
3753 3754 3755 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3753 def self_link @self_link end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
3758 3759 3760 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3758 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3765 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @envoy_headers = args[:envoy_headers] if args.key?(:envoy_headers) @interception_port = args[:interception_port] if args.key?(:interception_port) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) @update_time = args[:update_time] if args.key?(:update_time) end |