Class: Google::Apis::NetworkservicesV1beta1::Mesh

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Mesh represents a logical configuration grouping for workload to workload communication within a service mesh. Routes that point to mesh dictate how requests are routed within this logical mesh boundary.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Mesh

Returns a new instance of Mesh.



3578
3579
3580
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3578

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3534
3535
3536
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3534

def create_time
  @create_time
end

#descriptionString

Optional. A free-text description of the resource. Max length 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


3539
3540
3541
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3539

def description
  @description
end

#envoy_headersString

Optional. Determines if envoy will insert internal debug headers into upstream requests. Other Envoy headers may still be injected. By default, envoy will not insert any debug headers. Corresponds to the JSON property envoyHeaders

Returns:

  • (String)


3546
3547
3548
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3546

def envoy_headers
  @envoy_headers
end

#interception_portFixnum

Optional. If set to a valid TCP port (1-65535), instructs the SIDECAR proxy to listen on the specified port of localhost (127.0.0.1) address. The SIDECAR proxy will expect all traffic to be redirected to this port regardless of its actual ip:port destination. If unset, a port '15001' is used as the interception port. This is applicable only for sidecar proxy deployments. Corresponds to the JSON property interceptionPort

Returns:

  • (Fixnum)


3555
3556
3557
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3555

def interception_port
  @interception_port
end

#labelsHash<String,String>

Optional. Set of label tags associated with the Mesh resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3560
3561
3562
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3560

def labels
  @labels
end

#nameString

Identifier. Name of the Mesh resource. It matches pattern projects/*/ locations/*/meshes/. Corresponds to the JSON property name

Returns:

  • (String)


3566
3567
3568
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3566

def name
  @name
end

Output only. Server-defined URL of this resource Corresponds to the JSON property selfLink

Returns:

  • (String)


3571
3572
3573
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3571

def self_link
  @self_link
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3576
3577
3578
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3576

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3583
3584
3585
3586
3587
3588
3589
3590
3591
3592
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3583

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @envoy_headers = args[:envoy_headers] if args.key?(:envoy_headers)
  @interception_port = args[:interception_port] if args.key?(:interception_port)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @update_time = args[:update_time] if args.key?(:update_time)
end