Class: Google::Apis::NetworkservicesV1beta1::ProducerExtension
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::ProducerExtension
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
ProducerExtension is a resource representing producer defined configuration
for their service extension.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#extension_settings ⇒ Google::Apis::NetworkservicesV1beta1::ProducerExtensionExtensionSettings
The configuration for the service that this
ProducerExtensionoffers. -
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#phase ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProducerExtension
constructor
A new instance of ProducerExtension.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProducerExtension
Returns a new instance of ProducerExtension.
4490 4491 4492 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4490 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
4447 4448 4449 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4447 def create_time @create_time end |
#description ⇒ String
Optional. A human-readable description of the resource.
Corresponds to the JSON property description
4452 4453 4454 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4452 def description @description end |
#etag ⇒ String
Optional. Etag of the resource. If this is provided, it must match the server'
s etag. If the provided etag does not match the server's etag, the request
will fail with a 409 ABORTED error.
Corresponds to the JSON property etag
4459 4460 4461 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4459 def etag @etag end |
#extension_settings ⇒ Google::Apis::NetworkservicesV1beta1::ProducerExtensionExtensionSettings
The configuration for the service that this ProducerExtension offers.
Corresponds to the JSON property extensionSettings
4464 4465 4466 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4464 def extension_settings @extension_settings end |
#labels ⇒ Hash<String,String>
Optional. Set of labels associated with the ProducerExtension resource. The
format must comply with [the following requirements]((https://cloud.google.com/
compute/docs/labeling-resources#requirements).
Corresponds to the JSON property labels
4471 4472 4473 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4471 def labels @labels end |
#name ⇒ String
Identifier. Name of the ProducerExtension resource in the following format:
projects/project/locations/location/producerExtensions/producer_extension
.
Corresponds to the JSON property name
4478 4479 4480 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4478 def name @name end |
#phase ⇒ String
Required. The phase in which this ProducerExtension should execute.
Corresponds to the JSON property phase
4483 4484 4485 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4483 def phase @phase end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
4488 4489 4490 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4488 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4495 4496 4497 4498 4499 4500 4501 4502 4503 4504 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4495 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @extension_settings = args[:extension_settings] if args.key?(:extension_settings) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @phase = args[:phase] if args.key?(:phase) @update_time = args[:update_time] if args.key?(:update_time) end |