Class: Google::Apis::NetworkservicesV1beta1::ServiceBinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

ServiceBinding can be used to: - Bind a Service Directory Service to be used in a BackendService resource. This feature will be deprecated soon. - Bind a Private Service Connect producer service to be used in consumer Cloud Service Mesh or Application Load Balancers. - Bind a Cloud Run service to be used in consumer Cloud Service Mesh or Application Load Balancers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceBinding

Returns a new instance of ServiceBinding.



4077
4078
4079
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4077

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4038
4039
4040
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4038

def create_time
  @create_time
end

#descriptionString

Optional. A free-text description of the resource. Max length 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


4043
4044
4045
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4043

def description
  @description
end

#labelsHash<String,String>

Optional. Set of label tags associated with the ServiceBinding resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4048
4049
4050
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4048

def labels
  @labels
end

#nameString

Identifier. Name of the ServiceBinding resource. It matches pattern projects/* /locations/*/serviceBindings/. Corresponds to the JSON property name

Returns:

  • (String)


4054
4055
4056
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4054

def name
  @name
end

#serviceString

Optional. The full Service Directory Service name of the format projects/*/ locations/*/namespaces/*/services/*. This field is for Service Directory integration which will be deprecated soon. Corresponds to the JSON property service

Returns:

  • (String)


4061
4062
4063
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4061

def service
  @service
end

#service_idString

Output only. The unique identifier of the Service Directory Service against which the ServiceBinding resource is validated. This is populated when the Service Binding resource is used in another resource (like Backend Service). This is of the UUID4 format. This field is for Service Directory integration which will be deprecated soon. Corresponds to the JSON property serviceId

Returns:

  • (String)


4070
4071
4072
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4070

def service_id
  @service_id
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4075
4076
4077
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4075

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4082
4083
4084
4085
4086
4087
4088
4089
4090
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4082

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @service = args[:service] if args.key?(:service)
  @service_id = args[:service_id] if args.key?(:service_id)
  @update_time = args[:update_time] if args.key?(:update_time)
end