Class: Google::Apis::NetworkservicesV1beta1::ServiceBinding
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::ServiceBinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
ServiceBinding can be used to: - Bind a Service Directory Service to be used in a BackendService resource. This feature will be deprecated soon. - Bind a Private Service Connect producer service to be used in consumer Cloud Service Mesh or Application Load Balancers. - Bind a Cloud Run service to be used in consumer Cloud Service Mesh or Application Load Balancers.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#service ⇒ String
Optional.
-
#service_id ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceBinding
constructor
A new instance of ServiceBinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceBinding
Returns a new instance of ServiceBinding.
3906 3907 3908 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3906 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
3867 3868 3869 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3867 def create_time @create_time end |
#description ⇒ String
Optional. A free-text description of the resource. Max length 1024 characters.
Corresponds to the JSON property description
3872 3873 3874 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3872 def description @description end |
#labels ⇒ Hash<String,String>
Optional. Set of label tags associated with the ServiceBinding resource.
Corresponds to the JSON property labels
3877 3878 3879 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3877 def labels @labels end |
#name ⇒ String
Identifier. Name of the ServiceBinding resource. It matches pattern projects/*
/locations/*/serviceBindings/.
Corresponds to the JSON property name
3883 3884 3885 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3883 def name @name end |
#service ⇒ String
Optional. The full Service Directory Service name of the format projects/*/
locations/*/namespaces/*/services/*. This field is for Service Directory
integration which will be deprecated soon.
Corresponds to the JSON property service
3890 3891 3892 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3890 def service @service end |
#service_id ⇒ String
Output only. The unique identifier of the Service Directory Service against
which the ServiceBinding resource is validated. This is populated when the
Service Binding resource is used in another resource (like Backend Service).
This is of the UUID4 format. This field is for Service Directory integration
which will be deprecated soon.
Corresponds to the JSON property serviceId
3899 3900 3901 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3899 def service_id @service_id end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
3904 3905 3906 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3904 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3911 3912 3913 3914 3915 3916 3917 3918 3919 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3911 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @service = args[:service] if args.key?(:service) @service_id = args[:service_id] if args.key?(:service_id) @update_time = args[:update_time] if args.key?(:update_time) end |