Class: Google::Apis::NetworkservicesV1beta1::ServiceBinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

ServiceBinding can be used to: - Bind a Service Directory Service to be used in a BackendService resource. This feature will be deprecated soon. - Bind a Private Service Connect producer service to be used in consumer Cloud Service Mesh or Application Load Balancers. - Bind a Cloud Run service to be used in consumer Cloud Service Mesh or Application Load Balancers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceBinding

Returns a new instance of ServiceBinding.



3887
3888
3889
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3848
3849
3850
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3848

def create_time
  @create_time
end

#descriptionString

Optional. A free-text description of the resource. Max length 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


3853
3854
3855
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3853

def description
  @description
end

#labelsHash<String,String>

Optional. Set of label tags associated with the ServiceBinding resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3858
3859
3860
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3858

def labels
  @labels
end

#nameString

Identifier. Name of the ServiceBinding resource. It matches pattern projects/* /locations/*/serviceBindings/. Corresponds to the JSON property name

Returns:

  • (String)


3864
3865
3866
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3864

def name
  @name
end

#serviceString

Optional. The full Service Directory Service name of the format projects/*/ locations/*/namespaces/*/services/*. This field is for Service Directory integration which will be deprecated soon. Corresponds to the JSON property service

Returns:

  • (String)


3871
3872
3873
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3871

def service
  @service
end

#service_idString

Output only. The unique identifier of the Service Directory Service against which the ServiceBinding resource is validated. This is populated when the Service Binding resource is used in another resource (like Backend Service). This is of the UUID4 format. This field is for Service Directory integration which will be deprecated soon. Corresponds to the JSON property serviceId

Returns:

  • (String)


3880
3881
3882
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3880

def service_id
  @service_id
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3885
3886
3887
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3885

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3892
3893
3894
3895
3896
3897
3898
3899
3900
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3892

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @service = args[:service] if args.key?(:service)
  @service_id = args[:service_id] if args.key?(:service_id)
  @update_time = args[:update_time] if args.key?(:update_time)
end