Class: Google::Apis::NetworkservicesV1beta1::ServiceLbPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

ServiceLbPolicy holds global load balancing and traffic distribution configuration that can be applied to a BackendService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceLbPolicy

Returns a new instance of ServiceLbPolicy.



3632
3633
3634
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3632

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_capacity_drainGoogle::Apis::NetworkservicesV1beta1::ServiceLbPolicyAutoCapacityDrain

Option to specify if an unhealthy IG/NEG should be considered for global load balancing and traffic routing. Corresponds to the JSON property autoCapacityDrain



3587
3588
3589
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3587

def auto_capacity_drain
  @auto_capacity_drain
end

#create_timeString

Output only. The timestamp when this resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3592
3593
3594
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3592

def create_time
  @create_time
end

#descriptionString

Optional. A free-text description of the resource. Max length 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


3597
3598
3599
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3597

def description
  @description
end

#failover_configGoogle::Apis::NetworkservicesV1beta1::ServiceLbPolicyFailoverConfig

Option to specify health based failover behavior. This is not related to Network load balancer FailoverPolicy. Corresponds to the JSON property failoverConfig



3603
3604
3605
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3603

def failover_config
  @failover_config
end

#isolation_configGoogle::Apis::NetworkservicesV1beta1::ServiceLbPolicyIsolationConfig

Configuration to provide isolation support for the associated Backend Service. Corresponds to the JSON property isolationConfig



3608
3609
3610
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3608

def isolation_config
  @isolation_config
end

#labelsHash<String,String>

Optional. Set of label tags associated with the ServiceLbPolicy resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3613
3614
3615
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3613

def labels
  @labels
end

#load_balancing_algorithmString

Optional. The type of load balancing algorithm to be used. The default behavior is WATERFALL_BY_REGION. Corresponds to the JSON property loadBalancingAlgorithm

Returns:

  • (String)


3619
3620
3621
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3619

def load_balancing_algorithm
  @load_balancing_algorithm
end

#nameString

Identifier. Name of the ServiceLbPolicy resource. It matches pattern projects/ project/locations/location/serviceLbPolicies/service_lb_policy_name`. Corresponds to the JSON propertyname`

Returns:

  • (String)


3625
3626
3627
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3625

def name
  @name
end

#update_timeString

Output only. The timestamp when this resource was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3630
3631
3632
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3630

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3637
3638
3639
3640
3641
3642
3643
3644
3645
3646
3647
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3637

def update!(**args)
  @auto_capacity_drain = args[:auto_capacity_drain] if args.key?(:auto_capacity_drain)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @failover_config = args[:failover_config] if args.key?(:failover_config)
  @isolation_config = args[:isolation_config] if args.key?(:isolation_config)
  @labels = args[:labels] if args.key?(:labels)
  @load_balancing_algorithm = args[:load_balancing_algorithm] if args.key?(:load_balancing_algorithm)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end