Class: Google::Apis::NetworkservicesV1beta1::TcpRoute
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::TcpRoute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
TcpRoute is the resource defining how TCP traffic should be routed by a Mesh/ Gateway resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#gateways ⇒ Array<String>
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#meshes ⇒ Array<String>
Optional.
-
#name ⇒ String
Identifier.
-
#rules ⇒ Array<Google::Apis::NetworkservicesV1beta1::TcpRouteRouteRule>
Required.
-
#self_link ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TcpRoute
constructor
A new instance of TcpRoute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TcpRoute
Returns a new instance of TcpRoute.
4873 4874 4875 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4873 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
4823 4824 4825 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4823 def create_time @create_time end |
#description ⇒ String
Optional. A free-text description of the resource. Max length 1024 characters.
Corresponds to the JSON property description
4828 4829 4830 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4828 def description @description end |
#gateways ⇒ Array<String>
Optional. Gateways defines a list of gateways this TcpRoute is attached to, as
one of the routing rules to route the requests served by the gateway. Each
gateway reference should match the pattern: projects/*/locations/*/gateways/
Corresponds to the JSON property gateways
4835 4836 4837 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4835 def gateways @gateways end |
#labels ⇒ Hash<String,String>
Optional. Set of label tags associated with the TcpRoute resource.
Corresponds to the JSON property labels
4840 4841 4842 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4840 def labels @labels end |
#meshes ⇒ Array<String>
Optional. Meshes defines a list of meshes this TcpRoute is attached to, as one
of the routing rules to route the requests served by the mesh. Each mesh
reference should match the pattern: projects/*/locations/*/meshes/ The
attached Mesh should be of a type SIDECAR
Corresponds to the JSON property meshes
4848 4849 4850 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4848 def meshes @meshes end |
#name ⇒ String
Identifier. Name of the TcpRoute resource. It matches pattern projects/*/
locations/*/tcpRoutes/tcp_route_name>.
Corresponds to the JSON property name
4854 4855 4856 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4854 def name @name end |
#rules ⇒ Array<Google::Apis::NetworkservicesV1beta1::TcpRouteRouteRule>
Required. Rules that define how traffic is routed and handled. At least one
RouteRule must be supplied. If there are multiple rules then the action taken
will be the first rule to match.
Corresponds to the JSON property rules
4861 4862 4863 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4861 def rules @rules end |
#self_link ⇒ String
Output only. Server-defined URL of this resource
Corresponds to the JSON property selfLink
4866 4867 4868 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4866 def self_link @self_link end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
4871 4872 4873 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4871 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4878 4879 4880 4881 4882 4883 4884 4885 4886 4887 4888 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4878 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @gateways = args[:gateways] if args.key?(:gateways) @labels = args[:labels] if args.key?(:labels) @meshes = args[:meshes] if args.key?(:meshes) @name = args[:name] if args.key?(:name) @rules = args[:rules] if args.key?(:rules) @self_link = args[:self_link] if args.key?(:self_link) @update_time = args[:update_time] if args.key?(:update_time) end |