Class: Google::Apis::NetworkservicesV1beta1::TcpRoute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

TcpRoute is the resource defining how TCP traffic should be routed by a Mesh/ Gateway resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TcpRoute

Returns a new instance of TcpRoute.



4139
4140
4141
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4139

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4089
4090
4091
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4089

def create_time
  @create_time
end

#descriptionString

Optional. A free-text description of the resource. Max length 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


4094
4095
4096
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4094

def description
  @description
end

#gatewaysArray<String>

Optional. Gateways defines a list of gateways this TcpRoute is attached to, as one of the routing rules to route the requests served by the gateway. Each gateway reference should match the pattern: projects/*/locations/*/gateways/ Corresponds to the JSON property gateways

Returns:

  • (Array<String>)


4101
4102
4103
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4101

def gateways
  @gateways
end

#labelsHash<String,String>

Optional. Set of label tags associated with the TcpRoute resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4106
4107
4108
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4106

def labels
  @labels
end

#meshesArray<String>

Optional. Meshes defines a list of meshes this TcpRoute is attached to, as one of the routing rules to route the requests served by the mesh. Each mesh reference should match the pattern: projects/*/locations/*/meshes/ The attached Mesh should be of a type SIDECAR Corresponds to the JSON property meshes

Returns:

  • (Array<String>)


4114
4115
4116
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4114

def meshes
  @meshes
end

#nameString

Identifier. Name of the TcpRoute resource. It matches pattern projects/*/ locations/*/tcpRoutes/tcp_route_name>. Corresponds to the JSON property name

Returns:

  • (String)


4120
4121
4122
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4120

def name
  @name
end

#rulesArray<Google::Apis::NetworkservicesV1beta1::TcpRouteRouteRule>

Required. Rules that define how traffic is routed and handled. At least one RouteRule must be supplied. If there are multiple rules then the action taken will be the first rule to match. Corresponds to the JSON property rules



4127
4128
4129
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4127

def rules
  @rules
end

Output only. Server-defined URL of this resource Corresponds to the JSON property selfLink

Returns:

  • (String)


4132
4133
4134
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4132

def self_link
  @self_link
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4137
4138
4139
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4137

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4144
4145
4146
4147
4148
4149
4150
4151
4152
4153
4154
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4144

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @gateways = args[:gateways] if args.key?(:gateways)
  @labels = args[:labels] if args.key?(:labels)
  @meshes = args[:meshes] if args.key?(:meshes)
  @name = args[:name] if args.key?(:name)
  @rules = args[:rules] if args.key?(:rules)
  @self_link = args[:self_link] if args.key?(:self_link)
  @update_time = args[:update_time] if args.key?(:update_time)
end