Class: Google::Apis::NetworkservicesV1beta1::TcpRoute
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::TcpRoute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
TcpRoute is the resource defining how TCP traffic should be routed by a Mesh/ Gateway resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#gateways ⇒ Array<String>
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#meshes ⇒ Array<String>
Optional.
-
#name ⇒ String
Identifier.
-
#rules ⇒ Array<Google::Apis::NetworkservicesV1beta1::TcpRouteRouteRule>
Required.
-
#self_link ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TcpRoute
constructor
A new instance of TcpRoute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TcpRoute
Returns a new instance of TcpRoute.
3821 3822 3823 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3821 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
3771 3772 3773 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3771 def create_time @create_time end |
#description ⇒ String
Optional. A free-text description of the resource. Max length 1024 characters.
Corresponds to the JSON property description
3776 3777 3778 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3776 def description @description end |
#gateways ⇒ Array<String>
Optional. Gateways defines a list of gateways this TcpRoute is attached to, as
one of the routing rules to route the requests served by the gateway. Each
gateway reference should match the pattern: projects/*/locations/*/gateways/
Corresponds to the JSON property gateways
3783 3784 3785 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3783 def gateways @gateways end |
#labels ⇒ Hash<String,String>
Optional. Set of label tags associated with the TcpRoute resource.
Corresponds to the JSON property labels
3788 3789 3790 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3788 def labels @labels end |
#meshes ⇒ Array<String>
Optional. Meshes defines a list of meshes this TcpRoute is attached to, as one
of the routing rules to route the requests served by the mesh. Each mesh
reference should match the pattern: projects/*/locations/*/meshes/ The
attached Mesh should be of a type SIDECAR
Corresponds to the JSON property meshes
3796 3797 3798 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3796 def meshes @meshes end |
#name ⇒ String
Identifier. Name of the TcpRoute resource. It matches pattern projects/*/
locations/*/tcpRoutes/tcp_route_name>.
Corresponds to the JSON property name
3802 3803 3804 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3802 def name @name end |
#rules ⇒ Array<Google::Apis::NetworkservicesV1beta1::TcpRouteRouteRule>
Required. Rules that define how traffic is routed and handled. At least one
RouteRule must be supplied. If there are multiple rules then the action taken
will be the first rule to match.
Corresponds to the JSON property rules
3809 3810 3811 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3809 def rules @rules end |
#self_link ⇒ String
Output only. Server-defined URL of this resource
Corresponds to the JSON property selfLink
3814 3815 3816 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3814 def self_link @self_link end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
3819 3820 3821 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3819 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3826 3827 3828 3829 3830 3831 3832 3833 3834 3835 3836 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3826 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @gateways = args[:gateways] if args.key?(:gateways) @labels = args[:labels] if args.key?(:labels) @meshes = args[:meshes] if args.key?(:meshes) @name = args[:name] if args.key?(:name) @rules = args[:rules] if args.key?(:rules) @self_link = args[:self_link] if args.key?(:self_link) @update_time = args[:update_time] if args.key?(:update_time) end |