Class: Google::Apis::NetworkservicesV1beta1::TcpRouteRouteAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

The specifications for routing traffic and applying associated policies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TcpRouteRouteAction

Returns a new instance of TcpRouteRouteAction.



4191
4192
4193
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4191

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationsArray<Google::Apis::NetworkservicesV1beta1::TcpRouteRouteDestination>

Optional. The destination services to which traffic should be forwarded. At least one destination service is required. Only one of route destination or original destination can be set. Corresponds to the JSON property destinations



4173
4174
4175
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4173

def destinations
  @destinations
end

#idle_timeoutString

Optional. Specifies the idle timeout for the selected route. The idle timeout is defined as the period in which there are no bytes sent or received on either the upstream or downstream connection. If not set, the default idle timeout is 30 seconds. If set to 0s, the timeout will be disabled. Corresponds to the JSON property idleTimeout

Returns:

  • (String)


4181
4182
4183
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4181

def idle_timeout
  @idle_timeout
end

#original_destinationBoolean Also known as: original_destination?

Optional. If true, Router will use the destination IP and port of the original connection as the destination of the request. Default is false. Only one of route destinations or original destination can be set. Corresponds to the JSON property originalDestination

Returns:

  • (Boolean)


4188
4189
4190
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4188

def original_destination
  @original_destination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4196
4197
4198
4199
4200
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4196

def update!(**args)
  @destinations = args[:destinations] if args.key?(:destinations)
  @idle_timeout = args[:idle_timeout] if args.key?(:idle_timeout)
  @original_destination = args[:original_destination] if args.key?(:original_destination)
end