Class: Google::Apis::NetworkservicesV1beta1::TcpRouteRouteAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

The specifications for routing traffic and applying associated policies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TcpRouteRouteAction

Returns a new instance of TcpRouteRouteAction.



3866
3867
3868
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3866

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destinationsArray<Google::Apis::NetworkservicesV1beta1::TcpRouteRouteDestination>

Optional. The destination services to which traffic should be forwarded. At least one destination service is required. Only one of route destination or original destination can be set. Corresponds to the JSON property destinations



3848
3849
3850
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3848

def destinations
  @destinations
end

#idle_timeoutString

Optional. Specifies the idle timeout for the selected route. The idle timeout is defined as the period in which there are no bytes sent or received on either the upstream or downstream connection. If not set, the default idle timeout is 30 seconds. If set to 0s, the timeout will be disabled. Corresponds to the JSON property idleTimeout

Returns:

  • (String)


3856
3857
3858
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3856

def idle_timeout
  @idle_timeout
end

#original_destinationBoolean Also known as: original_destination?

Optional. If true, Router will use the destination IP and port of the original connection as the destination of the request. Default is false. Only one of route destinations or original destination can be set. Corresponds to the JSON property originalDestination

Returns:

  • (Boolean)


3863
3864
3865
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3863

def original_destination
  @original_destination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3871
3872
3873
3874
3875
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3871

def update!(**args)
  @destinations = args[:destinations] if args.key?(:destinations)
  @idle_timeout = args[:idle_timeout] if args.key?(:idle_timeout)
  @original_destination = args[:original_destination] if args.key?(:original_destination)
end