Class: Google::Apis::NetworkservicesV1beta1::TcpRouteRouteMatch

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

RouteMatch defines the predicate used to match requests to a given action. Multiple match types are "OR"ed for evaluation. If no routeMatch field is specified, this rule will unconditionally match traffic.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TcpRouteRouteMatch

Returns a new instance of TcpRouteRouteMatch.



3932
3933
3934
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3932

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Required. Must be specified in the CIDR range format. A CIDR range consists of an IP Address and a prefix length to construct the subnet mask. By default, the prefix length is 32 (i.e. matches a single IP address). Only IPV4 addresses are supported. Examples: "10.0.0.1" - matches against this exact IP address. "10.0.0.0/8" - matches against any IP address within the 10.0.0.0 subnet and 255.255.255.0 mask. "0.0.0.0/0" - matches against any IP address'. Corresponds to the JSON property address

Returns:

  • (String)


3925
3926
3927
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3925

def address
  @address
end

#portString

Required. Specifies the destination port to match against. Corresponds to the JSON property port

Returns:

  • (String)


3930
3931
3932
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3930

def port
  @port
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3937
3938
3939
3940
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 3937

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @port = args[:port] if args.key?(:port)
end