Class: Google::Apis::NetworkservicesV1beta1::TlsRouteRouteAction
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::TlsRouteRouteAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
The specifications for routing traffic and applying associated policies.
Instance Attribute Summary collapse
-
#destinations ⇒ Array<Google::Apis::NetworkservicesV1beta1::TlsRouteRouteDestination>
Required.
-
#idle_timeout ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TlsRouteRouteAction
constructor
A new instance of TlsRouteRouteAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TlsRouteRouteAction
Returns a new instance of TlsRouteRouteAction.
4589 4590 4591 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4589 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destinations ⇒ Array<Google::Apis::NetworkservicesV1beta1::TlsRouteRouteDestination>
Required. The destination services to which traffic should be forwarded. At
least one destination service is required.
Corresponds to the JSON property destinations
4579 4580 4581 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4579 def destinations @destinations end |
#idle_timeout ⇒ String
Optional. Specifies the idle timeout for the selected route. The idle timeout
is defined as the period in which there are no bytes sent or received on
either the upstream or downstream connection. If not set, the default idle
timeout is 1 hour. If set to 0s, the timeout will be disabled.
Corresponds to the JSON property idleTimeout
4587 4588 4589 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4587 def idle_timeout @idle_timeout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4594 4595 4596 4597 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4594 def update!(**args) @destinations = args[:destinations] if args.key?(:destinations) @idle_timeout = args[:idle_timeout] if args.key?(:idle_timeout) end |