Class: Google::Apis::NetworkservicesV1beta1::TlsRouteRouteDestination

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Describe the destination for traffic to be routed to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TlsRouteRouteDestination

Returns a new instance of TlsRouteRouteDestination.



4420
4421
4422
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4420

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#service_nameString

Required. The URL of a BackendService to route traffic to. Corresponds to the JSON property serviceName

Returns:

  • (String)


4410
4411
4412
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4410

def service_name
  @service_name
end

#weightFixnum

Optional. Specifies the proportion of requests forwarded to the backend referenced by the service_name field. This is computed as: - weight/Sum( weights in destinations) Weights in all destinations does not need to sum up to 100. Corresponds to the JSON property weight

Returns:

  • (Fixnum)


4418
4419
4420
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4418

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4425
4426
4427
4428
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4425

def update!(**args)
  @service_name = args[:service_name] if args.key?(:service_name)
  @weight = args[:weight] if args.key?(:weight)
end