Class: Google::Apis::NetworkservicesV1beta1::WasmPlugin
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::WasmPlugin
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
WasmPlugin is a resource representing a service executing a customer-
provided Wasm module.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#kms_key_name ⇒ String
Optional.
-
#kms_key_version ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#log_config ⇒ Google::Apis::NetworkservicesV1beta1::WasmPluginLogConfig
Specifies the logging options for the activity performed by this plugin.
-
#main_version_id ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
-
#used_by ⇒ Array<Google::Apis::NetworkservicesV1beta1::WasmPluginUsedBy>
Output only.
-
#versions ⇒ Hash<String,Google::Apis::NetworkservicesV1beta1::WasmPluginVersionDetails>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WasmPlugin
constructor
A new instance of WasmPlugin.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WasmPlugin
Returns a new instance of WasmPlugin.
4609 4610 4611 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4609 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
4521 4522 4523 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4521 def create_time @create_time end |
#description ⇒ String
Optional. A human-readable description of the resource.
Corresponds to the JSON property description
4526 4527 4528 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4526 def description @description end |
#kms_key_name ⇒ String
Optional. The name of the customer-managed CryptoKey to be
used to encrypt the WasmPlugin image (provided by image_uri) and
configuration (provided by plugin_config_data or plugin_config_uri) that are
stored by the Service Extensions product at rest. Format: projects/project
/locations/location/keyRings/keyring/cryptoKeys/key`By default, Google
Cloud automatically encrypts all data at rest using Google-owned and Google-
managed encryption keys. If you need ownership and control of the keys that
protect your data at rest, you can specify a customer-managed encryption key (
CMEK) to encrypt yourWasmPlugindata. For more information, see [Using
customer-managed encryption keys](https://cloud.google.com/service-extensions/
docs/cmek).
Corresponds to the JSON propertykmsKeyName`
4542 4543 4544 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4542 def kms_key_name @kms_key_name end |
#kms_key_version ⇒ String
Output only. The name of the specific CryptoKeyVersion used to encrypt the WasmPlugin data, if the kms_key_name
field is set. Format: projects/project/locations/location/keyRings/
keyring/cryptoKeys/key/cryptoKeyVersions/version`This is a read-only
field.WasmPlugindata is automatically encrypted using the most recent
CryptoKeyVersionof theCryptoKeyprovided in thekms_key_namefield. See
[Cloud KMS resources](https://cloud.google.com/kms/docs/resource-hierarchy)
for more information.
Corresponds to the JSON propertykmsKeyVersion`
4555 4556 4557 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4555 def kms_key_version @kms_key_version end |
#labels ⇒ Hash<String,String>
Optional. Set of labels associated with the WasmPlugin resource. The format
must comply with the following requirements.
Corresponds to the JSON property labels
4562 4563 4564 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4562 def labels @labels end |
#log_config ⇒ Google::Apis::NetworkservicesV1beta1::WasmPluginLogConfig
Specifies the logging options for the activity performed by this plugin. If
logging is enabled, plugin logs are exported to Cloud Logging.
Corresponds to the JSON property logConfig
4568 4569 4570 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4568 def log_config @log_config end |
#main_version_id ⇒ String
Optional. The ID of the WasmPluginVersion resource that is the currently
serving one. The version referred to must be a child of this WasmPlugin
resource.
Corresponds to the JSON property mainVersionId
4575 4576 4577 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4575 def main_version_id @main_version_id end |
#name ⇒ String
Identifier. Name of the WasmPlugin resource in the following format:
projects/project/locations/location/wasmPlugins/wasm_plugin`.
Corresponds to the JSON propertyname`
4581 4582 4583 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4581 def name @name end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
4586 4587 4588 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4586 def update_time @update_time end |
#used_by ⇒ Array<Google::Apis::NetworkservicesV1beta1::WasmPluginUsedBy>
Output only. List of all extensions that use this WasmPlugin resource.
Corresponds to the JSON property usedBy
4592 4593 4594 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4592 def used_by @used_by end |
#versions ⇒ Hash<String,Google::Apis::NetworkservicesV1beta1::WasmPluginVersionDetails>
Optional. All versions of this WasmPlugin resource in the key-value format.
The key is the resource ID, and the value is the VersionDetails object. Lets
you create or update a WasmPlugin resource and its versions in a single
request. When the main_version_id field is not empty, it must point to one
of the VersionDetails objects in the map. If provided in a PATCH request,
the new versions replace the previous set. Any version omitted from the
versions field is removed. Because the WasmPluginVersion resource is
immutable, if a WasmPluginVersion resource with the same name already exists
and differs, the request fails. Note: In a GET request, this field is
populated only if the field GetWasmPluginRequest.view is set to
WASM_PLUGIN_VIEW_FULL.
Corresponds to the JSON property versions
4607 4608 4609 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4607 def versions @versions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4614 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @kms_key_version = args[:kms_key_version] if args.key?(:kms_key_version) @labels = args[:labels] if args.key?(:labels) @log_config = args[:log_config] if args.key?(:log_config) @main_version_id = args[:main_version_id] if args.key?(:main_version_id) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) @used_by = args[:used_by] if args.key?(:used_by) @versions = args[:versions] if args.key?(:versions) end |