Class: Google::Apis::NetworkservicesV1beta1::WasmPlugin

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

WasmPlugin is a resource representing a service executing a customer- provided Wasm module.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WasmPlugin

Returns a new instance of WasmPlugin.



4612
4613
4614
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4612

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4528
4529
4530
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4528

def create_time
  @create_time
end

#descriptionString

Optional. A human-readable description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


4533
4534
4535
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4533

def description
  @description
end

#kms_key_nameString

Optional. The name of the customer managed Cloud KMS key to be used to encrypt the WasmPlugin image (provided by image_uri) and configuration (provided by plugin_config_data or plugin_config_uri) that are stored by the Service Extensions product at rest. Format: "projects/project/locations/location/ keyRings/keyring/cryptoKeys/key" By default, Google Cloud automatically encrypts all data at rest using Google-owned and Google-managed encryption keys. If you need ownership and control of the keys that protect your data at rest, you can specify a customer-managed encryption key (CMEK) to encrypt your WasmPlugin data. For more information, see Using customer-managed encryption keys. Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


4547
4548
4549
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4547

def kms_key_name
  @kms_key_name
end

#kms_key_versionString

Output only. The name of the specific CryptoKeyVersion used to encrypt the WasmPlugin data, if the kms_key_name field is set. Format: "projects/project /locations/location/keyRings/keyring/cryptoKeys/key/cryptoKeyVersions/ version" This is a read-only field. WasmPlugin data is automatically encrypted using the most recent CryptoKeyVersion of the CryptoKey provided in the kms_key_name field. See Cloud KMS resources for more information. Corresponds to the JSON property kmsKeyVersion

Returns:

  • (String)


4558
4559
4560
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4558

def kms_key_version
  @kms_key_version
end

#labelsHash<String,String>

Optional. Set of labels associated with the WasmPlugin resource. The format must comply with the following requirements. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4565
4566
4567
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4565

def labels
  @labels
end

#log_configGoogle::Apis::NetworkservicesV1beta1::WasmPluginLogConfig

Specifies the logging options for the activity performed by this plugin. If logging is enabled, plugin logs are exported to Cloud Logging. Corresponds to the JSON property logConfig



4571
4572
4573
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4571

def log_config
  @log_config
end

#main_version_idString

Optional. The ID of the WasmPluginVersion resource that is the currently serving one. The version referred to must be a child of this WasmPlugin resource. Corresponds to the JSON property mainVersionId

Returns:

  • (String)


4578
4579
4580
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4578

def main_version_id
  @main_version_id
end

#nameString

Identifier. Name of the WasmPlugin resource in the following format: projects/project/locations/location/wasmPlugins/wasm_plugin`. Corresponds to the JSON propertyname`

Returns:

  • (String)


4584
4585
4586
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4584

def name
  @name
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4589
4590
4591
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4589

def update_time
  @update_time
end

#used_byArray<Google::Apis::NetworkservicesV1beta1::WasmPluginUsedBy>

Output only. List of all extensions that use this WasmPlugin resource. Corresponds to the JSON property usedBy



4595
4596
4597
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4595

def used_by
  @used_by
end

#versionsHash<String,Google::Apis::NetworkservicesV1beta1::WasmPluginVersionDetails>

Optional. All versions of this WasmPlugin resource in the key-value format. The key is the resource ID, and the value is the VersionDetails object. Lets you create or update a WasmPlugin resource and its versions in a single request. When the main_version_id field is not empty, it must point to one of the VersionDetails objects in the map. If provided in a PATCH request, the new versions replace the previous set. Any version omitted from the versions field is removed. Because the WasmPluginVersion resource is immutable, if a WasmPluginVersion resource with the same name already exists and differs, the request fails. Note: In a GET request, this field is populated only if the field GetWasmPluginRequest.view is set to WASM_PLUGIN_VIEW_FULL. Corresponds to the JSON property versions



4610
4611
4612
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4610

def versions
  @versions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4617
4618
4619
4620
4621
4622
4623
4624
4625
4626
4627
4628
4629
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4617

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
  @kms_key_version = args[:kms_key_version] if args.key?(:kms_key_version)
  @labels = args[:labels] if args.key?(:labels)
  @log_config = args[:log_config] if args.key?(:log_config)
  @main_version_id = args[:main_version_id] if args.key?(:main_version_id)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @used_by = args[:used_by] if args.key?(:used_by)
  @versions = args[:versions] if args.key?(:versions)
end