Class: Google::Apis::NetworkservicesV1beta1::WasmPlugin
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::WasmPlugin
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
WasmPlugin is a resource representing a service executing a customer-
provided Wasm module.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#kms_key_name ⇒ String
Optional.
-
#kms_key_version ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#log_config ⇒ Google::Apis::NetworkservicesV1beta1::WasmPluginLogConfig
Specifies the logging options for the activity performed by this plugin.
-
#main_version_id ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
-
#used_by ⇒ Array<Google::Apis::NetworkservicesV1beta1::WasmPluginUsedBy>
Output only.
-
#versions ⇒ Hash<String,Google::Apis::NetworkservicesV1beta1::WasmPluginVersionDetails>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WasmPlugin
constructor
A new instance of WasmPlugin.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WasmPlugin
Returns a new instance of WasmPlugin.
4287 4288 4289 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4287 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
4203 4204 4205 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4203 def create_time @create_time end |
#description ⇒ String
Optional. A human-readable description of the resource.
Corresponds to the JSON property description
4208 4209 4210 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4208 def description @description end |
#kms_key_name ⇒ String
Optional. The name of the customer managed Cloud KMS key to be used to encrypt
the WasmPlugin image (provided by image_uri) and configuration (provided by
plugin_config_data or plugin_config_uri) that are stored by the Service
Extensions product at rest. Format: "projects/project/locations/location/
keyRings/keyring/cryptoKeys/key" By default, Google Cloud automatically
encrypts all data at rest using Google-owned and Google-managed encryption
keys. If you need ownership and control of the keys that protect your data at
rest, you can specify a customer-managed encryption key (CMEK) to encrypt your
WasmPlugin data. For more information, see Using customer-managed
encryption keys.
Corresponds to the JSON property kmsKeyName
4222 4223 4224 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4222 def kms_key_name @kms_key_name end |
#kms_key_version ⇒ String
Output only. The name of the specific CryptoKeyVersion used to encrypt the
WasmPlugin data, if the kms_key_name field is set. Format: "projects/project
/locations/location/keyRings/keyring/cryptoKeys/key/cryptoKeyVersions/
version" This is a read-only field. WasmPlugin data is automatically
encrypted using the most recent CryptoKeyVersion of the CryptoKey provided
in the kms_key_name field. See Cloud KMS resources for more information.
Corresponds to the JSON property kmsKeyVersion
4233 4234 4235 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4233 def kms_key_version @kms_key_version end |
#labels ⇒ Hash<String,String>
Optional. Set of labels associated with the WasmPlugin resource. The format
must comply with the following requirements.
Corresponds to the JSON property labels
4240 4241 4242 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4240 def labels @labels end |
#log_config ⇒ Google::Apis::NetworkservicesV1beta1::WasmPluginLogConfig
Specifies the logging options for the activity performed by this plugin. If
logging is enabled, plugin logs are exported to Cloud Logging.
Corresponds to the JSON property logConfig
4246 4247 4248 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4246 def log_config @log_config end |
#main_version_id ⇒ String
Optional. The ID of the WasmPluginVersion resource that is the currently
serving one. The version referred to must be a child of this WasmPlugin
resource.
Corresponds to the JSON property mainVersionId
4253 4254 4255 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4253 def main_version_id @main_version_id end |
#name ⇒ String
Identifier. Name of the WasmPlugin resource in the following format:
projects/project/locations/location/wasmPlugins/wasm_plugin`.
Corresponds to the JSON propertyname`
4259 4260 4261 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4259 def name @name end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
4264 4265 4266 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4264 def update_time @update_time end |
#used_by ⇒ Array<Google::Apis::NetworkservicesV1beta1::WasmPluginUsedBy>
Output only. List of all extensions that use this WasmPlugin resource.
Corresponds to the JSON property usedBy
4270 4271 4272 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4270 def used_by @used_by end |
#versions ⇒ Hash<String,Google::Apis::NetworkservicesV1beta1::WasmPluginVersionDetails>
Optional. All versions of this WasmPlugin resource in the key-value format.
The key is the resource ID, and the value is the VersionDetails object. Lets
you create or update a WasmPlugin resource and its versions in a single
request. When the main_version_id field is not empty, it must point to one
of the VersionDetails objects in the map. If provided in a PATCH request,
the new versions replace the previous set. Any version omitted from the
versions field is removed. Because the WasmPluginVersion resource is
immutable, if a WasmPluginVersion resource with the same name already exists
and differs, the request fails. Note: In a GET request, this field is
populated only if the field GetWasmPluginRequest.view is set to
WASM_PLUGIN_VIEW_FULL.
Corresponds to the JSON property versions
4285 4286 4287 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4285 def versions @versions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4292 4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4292 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @kms_key_version = args[:kms_key_version] if args.key?(:kms_key_version) @labels = args[:labels] if args.key?(:labels) @log_config = args[:log_config] if args.key?(:log_config) @main_version_id = args[:main_version_id] if args.key?(:main_version_id) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) @used_by = args[:used_by] if args.key?(:used_by) @versions = args[:versions] if args.key?(:versions) end |