Class: Google::Apis::NetworkservicesV1beta1::WasmPluginLogConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Specifies the logging options for the activity performed by this plugin. If logging is enabled, plugin logs are exported to Cloud Logging.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WasmPluginLogConfig

Returns a new instance of WasmPluginLogConfig.



4858
4859
4860
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4858

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enableBoolean Also known as: enable?

Optional. Specifies whether to enable logging for activity by this plugin. Defaults to false. Corresponds to the JSON property enable

Returns:

  • (Boolean)


4835
4836
4837
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4835

def enable
  @enable
end

#min_log_levelString

Optional. Non-empty default. Specifies the lowest level of the plugin logs that are exported to Cloud Logging. This setting relates to the logs generated by using logging statements in your Wasm code. This field is can be set only if logging is enabled for the plugin. If the field is not provided when logging is enabled, it is set to INFO by default. Corresponds to the JSON property minLogLevel

Returns:

  • (String)


4845
4846
4847
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4845

def min_log_level
  @min_log_level
end

#sample_rateFloat

Optional. Non-empty default. Configures the sampling rate of activity logs, where 1.0 means all logged activity is reported and 0.0 means no activity is reported. A floating point value between 0.0 and 1.0 indicates that a percentage of log messages is stored. The default value when logging is enabled is 1.0. The value of the field must be between 0 and 1 ( inclusive). This field can be specified only if logging is enabled for this plugin. Corresponds to the JSON property sampleRate

Returns:

  • (Float)


4856
4857
4858
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4856

def sample_rate
  @sample_rate
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4863
4864
4865
4866
4867
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4863

def update!(**args)
  @enable = args[:enable] if args.key?(:enable)
  @min_log_level = args[:min_log_level] if args.key?(:min_log_level)
  @sample_rate = args[:sample_rate] if args.key?(:sample_rate)
end