Class: Google::Apis::NetworkservicesV1beta1::WasmPluginLogConfig
- Inherits:
-
Object
- Object
- Google::Apis::NetworkservicesV1beta1::WasmPluginLogConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb
Overview
Specifies the logging options for the activity performed by this plugin. If logging is enabled, plugin logs are exported to Cloud Logging.
Instance Attribute Summary collapse
-
#enable ⇒ Boolean
(also: #enable?)
Optional.
-
#min_log_level ⇒ String
Non-empty default.
-
#sample_rate ⇒ Float
Non-empty default.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WasmPluginLogConfig
constructor
A new instance of WasmPluginLogConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WasmPluginLogConfig
Returns a new instance of WasmPluginLogConfig.
4338 4339 4340 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4338 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable ⇒ Boolean Also known as: enable?
Optional. Specifies whether to enable logging for activity by this plugin.
Defaults to false.
Corresponds to the JSON property enable
4316 4317 4318 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4316 def enable @enable end |
#min_log_level ⇒ String
Non-empty default. Specifies the lowest level of the plugin logs that are
exported to Cloud Logging. This setting relates to the logs generated by using
logging statements in your Wasm code. This field is can be set only if logging
is enabled for the plugin. If the field is not provided when logging is
enabled, it is set to INFO by default.
Corresponds to the JSON property minLogLevel
4326 4327 4328 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4326 def min_log_level @min_log_level end |
#sample_rate ⇒ Float
Non-empty default. Configures the sampling rate of activity logs, where 1.0
means all logged activity is reported and 0.0 means no activity is reported.
A floating point value between 0.0 and 1.0 indicates that a percentage of
log messages is stored. The default value when logging is enabled is 1.0.
The value of the field must be between 0 and 1 (inclusive). This field can
be specified only if logging is enabled for this plugin.
Corresponds to the JSON property sampleRate
4336 4337 4338 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4336 def sample_rate @sample_rate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4343 4344 4345 4346 4347 |
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4343 def update!(**args) @enable = args[:enable] if args.key?(:enable) @min_log_level = args[:min_log_level] if args.key?(:min_log_level) @sample_rate = args[:sample_rate] if args.key?(:sample_rate) end |