Class: Google::Apis::NetworkservicesV1beta1::WasmPluginVersionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkservices_v1beta1/classes.rb,
lib/google/apis/networkservices_v1beta1/representations.rb,
lib/google/apis/networkservices_v1beta1/representations.rb

Overview

Details of a WasmPluginVersion resource to be inlined in the WasmPlugin resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WasmPluginVersionDetails

Returns a new instance of WasmPluginVersionDetails.



4567
4568
4569
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4567

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4490
4491
4492
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4490

def create_time
  @create_time
end

#descriptionString

Optional. A human-readable description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


4495
4496
4497
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4495

def description
  @description
end

#image_digestString

Output only. This field holds the digest (usually checksum) value for the plugin image. The value is calculated based on the image_uri field. If the image_uri field refers to a container image, the digest value is obtained from the container image. If the image_uri field refers to a generic artifact, the digest value is calculated based on the contents of the file. Corresponds to the JSON property imageDigest

Returns:

  • (String)


4504
4505
4506
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4504

def image_digest
  @image_digest
end

#image_uriString

Optional. URI of the image containing the Wasm module, stored in Artifact Registry. The URI can refer to one of the following repository formats: * Container images: the image_uri must point to a container that contains a single file with the name plugin.wasm. When a new WasmPluginVersion resource is created, the digest of the image is saved in the image_digest field. When pulling a container image from Artifact Registry, the digest value is used instead of an image tag. * Generic artifacts: the image_uri must be in this format: projects/project/locations/location/repositories/ repository/ genericArtifacts/package:version`. The specified package and version must contain a file with the nameplugin.wasm. When a new WasmPluginVersionresource is created, the checksum of the contents of the file is saved in theimage_digestfield. Corresponds to the JSON propertyimageUri`

Returns:

  • (String)


4520
4521
4522
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4520

def image_uri
  @image_uri
end

#labelsHash<String,String>

Optional. Set of labels associated with the WasmPluginVersion resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4525
4526
4527
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4525

def labels
  @labels
end

#plugin_config_dataString

Configuration for the plugin. The configuration is provided to the plugin at runtime through the ON_CONFIGURE callback. When a new WasmPluginVersion version is created, the digest of the contents is saved in the plugin_config_digest field. Corresponds to the JSON property pluginConfigData NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


4534
4535
4536
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4534

def plugin_config_data
  @plugin_config_data
end

#plugin_config_digestString

Output only. This field holds the digest (usually checksum) value for the plugin configuration. The value is calculated based on the contents of plugin_config_data field or the image defined by the plugin_config_uri field. Corresponds to the JSON property pluginConfigDigest

Returns:

  • (String)


4542
4543
4544
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4542

def plugin_config_digest
  @plugin_config_digest
end

#plugin_config_uriString

URI of the plugin configuration stored in the Artifact Registry. The configuration is provided to the plugin at runtime through the ON_CONFIGURE callback. The URI can refer to one of the following repository formats: * Container images: the plugin_config_uri must point to a container that contains a single file with the name plugin.config. When a new WasmPluginVersion resource is created, the digest of the image is saved in the plugin_config_digest field. When pulling a container image from Artifact Registry, the digest value is used instead of an image tag. * Generic artifacts: the plugin_config_uri must be in this format: projects/project/ locations/location/repositories/repository/ genericArtifacts/package: version`. The specified package and version must contain a file with the name plugin.config. When a newWasmPluginVersionresource is created, the checksum of the contents of the file is saved in theplugin_config_digest field. Corresponds to the JSON propertypluginConfigUri`

Returns:

  • (String)


4560
4561
4562
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4560

def plugin_config_uri
  @plugin_config_uri
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4565
4566
4567
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4565

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4572
4573
4574
4575
4576
4577
4578
4579
4580
4581
4582
# File 'lib/google/apis/networkservices_v1beta1/classes.rb', line 4572

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @image_digest = args[:image_digest] if args.key?(:image_digest)
  @image_uri = args[:image_uri] if args.key?(:image_uri)
  @labels = args[:labels] if args.key?(:labels)
  @plugin_config_data = args[:plugin_config_data] if args.key?(:plugin_config_data)
  @plugin_config_digest = args[:plugin_config_digest] if args.key?(:plugin_config_digest)
  @plugin_config_uri = args[:plugin_config_uri] if args.key?(:plugin_config_uri)
  @update_time = args[:update_time] if args.key?(:update_time)
end